# Autogenerated. Do not modify.
#
# Profile: 21.60
from enum import Enum


class ProfileType(Enum):
    ACTIVITY = 0
    ACTIVITY_CLASS = 1
    ACTIVITY_LEVEL = 2
    ACTIVITY_SUBTYPE = 3
    ACTIVITY_TYPE = 4
    ANALOG_WATCHFACE_LAYOUT = 5
    ANTPLUS_DEVICE_TYPE = 6
    ANT_NETWORK = 7
    ATTITUDE_STAGE = 8
    ATTITUDE_VALIDITY = 9
    AUTOLAP_TRIGGER = 10
    AUTOSCROLL = 11
    AUTO_ACTIVITY_DETECT = 12
    AUTO_SYNC_FREQUENCY = 13
    BACKLIGHT_MODE = 14
    BACKLIGHT_TIMEOUT = 15
    BATTERY_STATUS = 16
    BENCH_PRESS_EXERCISE_NAME = 17
    BIKE_LIGHT_BEAM_ANGLE_MODE = 18
    BIKE_LIGHT_NETWORK_CONFIG_TYPE = 19
    BODY_LOCATION = 20
    BP_STATUS = 21
    CALF_RAISE_EXERCISE_NAME = 22
    CAMERA_EVENT_TYPE = 23
    CAMERA_ORIENTATION_TYPE = 24
    CARDIO_EXERCISE_NAME = 25
    CARRY_EXERCISE_NAME = 26
    CHECKSUM = 27
    CHOP_EXERCISE_NAME = 28
    CLIMB_PRO_EVENT = 29
    COMM_TIMEOUT_TYPE = 30
    CONNECTIVITY_CAPABILITIES = 31
    CORE_EXERCISE_NAME = 32
    COURSE_CAPABILITIES = 33
    COURSE_POINT = 34
    CRUNCH_EXERCISE_NAME = 35
    CURL_EXERCISE_NAME = 36
    DATE_MODE = 37
    DATE_TIME = 38
    DAY_OF_WEEK = 39
    DEADLIFT_EXERCISE_NAME = 40
    DEVICE_INDEX = 41
    DIGITAL_WATCHFACE_LAYOUT = 42
    DISPLAY_HEART = 43
    DISPLAY_MEASURE = 44
    DISPLAY_ORIENTATION = 45
    DISPLAY_POSITION = 46
    DISPLAY_POWER = 47
    DIVE_ALARM_TYPE = 48
    DIVE_BACKLIGHT_MODE = 49
    DIVE_GAS_STATUS = 50
    EVENT = 51
    EVENT_TYPE = 52
    EXD_DATA_UNITS = 53
    EXD_DESCRIPTORS = 54
    EXD_DISPLAY_TYPE = 55
    EXD_LAYOUT = 56
    EXD_QUALIFIERS = 57
    EXERCISE_CATEGORY = 58
    FAVERO_PRODUCT = 59
    FILE = 60
    FILE_FLAGS = 61
    FITNESS_EQUIPMENT_STATE = 62
    FIT_BASE_UNIT = 63
    FLYE_EXERCISE_NAME = 64
    GARMIN_PRODUCT = 65
    GENDER = 66
    GOAL = 67
    GOAL_RECURRENCE = 68
    GOAL_SOURCE = 69
    HIP_RAISE_EXERCISE_NAME = 70
    HIP_STABILITY_EXERCISE_NAME = 71
    HIP_SWING_EXERCISE_NAME = 72
    HR_TYPE = 73
    HR_ZONE_CALC = 74
    HYPEREXTENSION_EXERCISE_NAME = 75
    INTENSITY = 76
    LANGUAGE = 77
    LANGUAGE_BITS_0 = 78
    LANGUAGE_BITS_1 = 79
    LANGUAGE_BITS_2 = 80
    LANGUAGE_BITS_3 = 81
    LANGUAGE_BITS_4 = 82
    LAP_TRIGGER = 83
    LATERAL_RAISE_EXERCISE_NAME = 84
    LEFT_RIGHT_BALANCE = 85
    LEFT_RIGHT_BALANCE_100 = 86
    LEG_CURL_EXERCISE_NAME = 87
    LEG_RAISE_EXERCISE_NAME = 88
    LENGTH_TYPE = 89
    LOCALTIME_INTO_DAY = 90
    LOCAL_DATE_TIME = 91
    LOCAL_DEVICE_TYPE = 92
    LUNGE_EXERCISE_NAME = 93
    MANUFACTURER = 94
    MESG_COUNT = 95
    MESG_NUM = 96
    MESSAGE_INDEX = 97
    OLYMPIC_LIFT_EXERCISE_NAME = 98
    PLANK_EXERCISE_NAME = 99
    PLYO_EXERCISE_NAME = 100
    POWER_PHASE_TYPE = 101
    PULL_UP_EXERCISE_NAME = 102
    PUSH_UP_EXERCISE_NAME = 103
    PWR_ZONE_CALC = 104
    RADAR_THREAT_LEVEL_TYPE = 105
    RIDER_POSITION_TYPE = 106
    ROW_EXERCISE_NAME = 107
    RUN_EXERCISE_NAME = 108
    SCHEDULE = 109
    SEGMENT_DELETE_STATUS = 110
    SEGMENT_LAP_STATUS = 111
    SEGMENT_LEADERBOARD_TYPE = 112
    SEGMENT_SELECTION_TYPE = 113
    SENSOR_TYPE = 114
    SESSION_TRIGGER = 115
    SET_TYPE = 116
    SHOULDER_PRESS_EXERCISE_NAME = 117
    SHOULDER_STABILITY_EXERCISE_NAME = 118
    SHRUG_EXERCISE_NAME = 119
    SIDE = 120
    SIT_UP_EXERCISE_NAME = 121
    SOURCE_TYPE = 122
    SPORT = 123
    SPORT_BITS_0 = 124
    SPORT_BITS_1 = 125
    SPORT_BITS_2 = 126
    SPORT_BITS_3 = 127
    SPORT_BITS_4 = 128
    SPORT_BITS_5 = 129
    SPORT_BITS_6 = 130
    SPORT_EVENT = 131
    SQUAT_EXERCISE_NAME = 132
    STROKE_TYPE = 133
    SUB_SPORT = 134
    SUPPORTED_EXD_SCREEN_LAYOUTS = 135
    SWIM_STROKE = 136
    SWITCH = 137
    TAP_SENSITIVITY = 138
    TIMER_TRIGGER = 139
    TIME_INTO_DAY = 140
    TIME_MODE = 141
    TIME_ZONE = 142
    TISSUE_MODEL_TYPE = 143
    TONE = 144
    TOTAL_BODY_EXERCISE_NAME = 145
    TRICEPS_EXTENSION_EXERCISE_NAME = 146
    TURN_TYPE = 147
    USER_LOCAL_ID = 148
    WARM_UP_EXERCISE_NAME = 149
    WATCHFACE_MODE = 150
    WATER_TYPE = 151
    WEATHER_REPORT = 152
    WEATHER_SEVERE_TYPE = 153
    WEATHER_SEVERITY = 154
    WEATHER_STATUS = 155
    WEIGHT = 156
    WORKOUT_CAPABILITIES = 157
    WORKOUT_EQUIPMENT = 158
    WORKOUT_HR = 159
    WORKOUT_POWER = 160
    WORKOUT_STEP_DURATION = 161
    WORKOUT_STEP_TARGET = 162


class FileType(Enum):
    DEVICE = 1
    SETTINGS = 2
    SPORT = 3
    ACTIVITY = 4
    WORKOUT = 5
    COURSE = 6
    SCHEDULES = 7
    WEIGHT = 9
    TOTALS = 10
    GOALS = 11
    BLOOD_PRESSURE = 14
    MONITORING_A = 15
    ACTIVITY_SUMMARY = 20
    MONITORING_DAILY = 28
    MONITORING_B = 32
    SEGMENT = 34
    SEGMENT_LIST = 35
    EXD_CONFIGURATION = 40
    MFG_RANGE_MIN = 247
    MFG_RANGE_MAX = 254


class MesgNum(Enum):
    FILE_ID = 0
    CAPABILITIES = 1
    DEVICE_SETTINGS = 2
    USER_PROFILE = 3
    HRM_PROFILE = 4
    SDM_PROFILE = 5
    BIKE_PROFILE = 6
    ZONES_TARGET = 7
    HR_ZONE = 8
    POWER_ZONE = 9
    MET_ZONE = 10
    SPORT = 12
    GOAL = 15
    SESSION = 18
    LAP = 19
    RECORD = 20
    EVENT = 21
    DEVICE_INFO = 23
    WORKOUT = 26
    WORKOUT_STEP = 27
    SCHEDULE = 28
    WEIGHT_SCALE = 30
    COURSE = 31
    COURSE_POINT = 32
    TOTALS = 33
    ACTIVITY = 34
    SOFTWARE = 35
    FILE_CAPABILITIES = 37
    MESG_CAPABILITIES = 38
    FIELD_CAPABILITIES = 39
    FILE_CREATOR = 49
    BLOOD_PRESSURE = 51
    SPEED_ZONE = 53
    MONITORING = 55
    TRAINING_FILE = 72
    HRV = 78
    ANT_RX = 80
    ANT_TX = 81
    ANT_CHANNEL_ID = 82
    LENGTH = 101
    MONITORING_INFO = 103
    PAD = 105
    SLAVE_DEVICE = 106
    CONNECTIVITY = 127
    WEATHER_CONDITIONS = 128
    WEATHER_ALERT = 129
    CADENCE_ZONE = 131
    HR = 132
    SEGMENT_LAP = 142
    MEMO_GLOB = 145
    SEGMENT_ID = 148
    SEGMENT_LEADERBOARD_ENTRY = 149
    SEGMENT_POINT = 150
    SEGMENT_FILE = 151
    WORKOUT_SESSION = 158
    WATCHFACE_SETTINGS = 159
    GPS_METADATA = 160
    CAMERA_EVENT = 161
    TIMESTAMP_CORRELATION = 162
    GYROSCOPE_DATA = 164
    ACCELEROMETER_DATA = 165
    THREE_D_SENSOR_CALIBRATION = 167
    VIDEO_FRAME = 169
    OBDII_DATA = 174
    NMEA_SENTENCE = 177
    AVIATION_ATTITUDE = 178
    VIDEO = 184
    VIDEO_TITLE = 185
    VIDEO_DESCRIPTION = 186
    VIDEO_CLIP = 187
    OHR_SETTINGS = 188
    EXD_SCREEN_CONFIGURATION = 200
    EXD_DATA_FIELD_CONFIGURATION = 201
    EXD_DATA_CONCEPT_CONFIGURATION = 202
    FIELD_DESCRIPTION = 206
    DEVELOPER_DATA_ID = 207
    MAGNETOMETER_DATA = 208
    BAROMETER_DATA = 209
    ONE_D_SENSOR_CALIBRATION = 210
    SET = 225
    STRESS_LEVEL = 227
    DIVE_SETTINGS = 258
    DIVE_GAS = 259
    DIVE_ALARM = 262
    EXERCISE_TITLE = 264
    DIVE_SUMMARY = 268
    JUMP = 285
    CLIMB_PRO = 317
    MFG_RANGE_MIN = 65280
    MFG_RANGE_MAX = 65534


class Checksum(Enum):
    CLEAR = 0
    OK = 1


class FileFlags(Enum):
    READ = 2
    WRITE = 4
    ERASE = 8


class MesgCount(Enum):
    NUM_PER_FILE = 0
    MAX_PER_FILE = 1
    MAX_PER_FILE_TYPE = 2


class LocalDateTime(Enum):
    MIN = 268435456


class MessageIndex(Enum):
    SELECTED = 32768
    RESERVED = 28672
    MASK = 4095


class DeviceIndex(Enum):
    CREATOR = 0


class Gender(Enum):
    FEMALE = 0
    MALE = 1


class Language(Enum):
    ENGLISH = 0
    FRENCH = 1
    ITALIAN = 2
    GERMAN = 3
    SPANISH = 4
    CROATIAN = 5
    CZECH = 6
    DANISH = 7
    DUTCH = 8
    FINNISH = 9
    GREEK = 10
    HUNGARIAN = 11
    NORWEGIAN = 12
    POLISH = 13
    PORTUGUESE = 14
    SLOVAKIAN = 15
    SLOVENIAN = 16
    SWEDISH = 17
    RUSSIAN = 18
    TURKISH = 19
    LATVIAN = 20
    UKRAINIAN = 21
    ARABIC = 22
    FARSI = 23
    BULGARIAN = 24
    ROMANIAN = 25
    CHINESE = 26
    JAPANESE = 27
    KOREAN = 28
    TAIWANESE = 29
    THAI = 30
    HEBREW = 31
    BRAZILIAN_PORTUGUESE = 32
    INDONESIAN = 33
    MALAYSIAN = 34
    VIETNAMESE = 35
    BURMESE = 36
    MONGOLIAN = 37
    CUSTOM = 254


class LanguageBits0(Enum):
    ENGLISH = 1
    FRENCH = 2
    ITALIAN = 4
    GERMAN = 8
    SPANISH = 16
    CROATIAN = 32
    CZECH = 64
    DANISH = 128


class LanguageBits1(Enum):
    DUTCH = 1
    FINNISH = 2
    GREEK = 4
    HUNGARIAN = 8
    NORWEGIAN = 16
    POLISH = 32
    PORTUGUESE = 64
    SLOVAKIAN = 128


class LanguageBits2(Enum):
    SLOVENIAN = 1
    SWEDISH = 2
    RUSSIAN = 4
    TURKISH = 8
    LATVIAN = 16
    UKRAINIAN = 32
    ARABIC = 64
    FARSI = 128


class LanguageBits3(Enum):
    BULGARIAN = 1
    ROMANIAN = 2
    CHINESE = 4
    JAPANESE = 8
    KOREAN = 16
    TAIWANESE = 32
    THAI = 64
    HEBREW = 128


class LanguageBits4(Enum):
    BRAZILIAN_PORTUGUESE = 1
    INDONESIAN = 2
    MALAYSIAN = 4
    VIETNAMESE = 8
    BURMESE = 16
    MONGOLIAN = 32


class TimeZone(Enum):
    ALMATY = 0
    BANGKOK = 1
    BOMBAY = 2
    BRASILIA = 3
    CAIRO = 4
    CAPE_VERDE_IS = 5
    DARWIN = 6
    ENIWETOK = 7
    FIJI = 8
    HONG_KONG = 9
    ISLAMABAD = 10
    KABUL = 11
    MAGADAN = 12
    MID_ATLANTIC = 13
    MOSCOW = 14
    MUSCAT = 15
    NEWFOUNDLAND = 16
    SAMOA = 17
    SYDNEY = 18
    TEHRAN = 19
    TOKYO = 20
    US_ALASKA = 21
    US_ATLANTIC = 22
    US_CENTRAL = 23
    US_EASTERN = 24
    US_HAWAII = 25
    US_MOUNTAIN = 26
    US_PACIFIC = 27
    OTHER = 28
    AUCKLAND = 29
    KATHMANDU = 30
    EUROPE_WESTERN_WET = 31
    EUROPE_CENTRAL_CET = 32
    EUROPE_EASTERN_EET = 33
    JAKARTA = 34
    PERTH = 35
    ADELAIDE = 36
    BRISBANE = 37
    TASMANIA = 38
    ICELAND = 39
    AMSTERDAM = 40
    ATHENS = 41
    BARCELONA = 42
    BERLIN = 43
    BRUSSELS = 44
    BUDAPEST = 45
    COPENHAGEN = 46
    DUBLIN = 47
    HELSINKI = 48
    LISBON = 49
    LONDON = 50
    MADRID = 51
    MUNICH = 52
    OSLO = 53
    PARIS = 54
    PRAGUE = 55
    REYKJAVIK = 56
    ROME = 57
    STOCKHOLM = 58
    VIENNA = 59
    WARSAW = 60
    ZURICH = 61
    QUEBEC = 62
    ONTARIO = 63
    MANITOBA = 64
    SASKATCHEWAN = 65
    ALBERTA = 66
    BRITISH_COLUMBIA = 67
    BOISE = 68
    BOSTON = 69
    CHICAGO = 70
    DALLAS = 71
    DENVER = 72
    KANSAS_CITY = 73
    LAS_VEGAS = 74
    LOS_ANGELES = 75
    MIAMI = 76
    MINNEAPOLIS = 77
    NEW_YORK = 78
    NEW_ORLEANS = 79
    PHOENIX = 80
    SANTA_FE = 81
    SEATTLE = 82
    WASHINGTON_DC = 83
    US_ARIZONA = 84
    CHITA = 85
    EKATERINBURG = 86
    IRKUTSK = 87
    KALININGRAD = 88
    KRASNOYARSK = 89
    NOVOSIBIRSK = 90
    PETROPAVLOVSK_KAMCHATSKIY = 91
    SAMARA = 92
    VLADIVOSTOK = 93
    MEXICO_CENTRAL = 94
    MEXICO_MOUNTAIN = 95
    MEXICO_PACIFIC = 96
    CAPE_TOWN = 97
    WINKHOEK = 98
    LAGOS = 99
    RIYAHD = 100
    VENEZUELA = 101
    AUSTRALIA_LH = 102
    SANTIAGO = 103
    MANUAL = 253
    AUTOMATIC = 254


class DisplayMeasure(Enum):
    METRIC = 0
    STATUTE = 1
    NAUTICAL = 2


class DisplayHeart(Enum):
    BPM = 0
    MAX = 1
    RESERVE = 2


class DisplayPower(Enum):
    WATTS = 0
    PERCENT_FTP = 1


class DisplayPosition(Enum):
    DEGREE = 0
    DEGREE_MINUTE = 1
    DEGREE_MINUTE_SECOND = 2
    AUSTRIAN_GRID = 3
    BRITISH_GRID = 4
    DUTCH_GRID = 5
    HUNGARIAN_GRID = 6
    FINNISH_GRID = 7
    GERMAN_GRID = 8
    ICELANDIC_GRID = 9
    INDONESIAN_EQUATORIAL = 10
    INDONESIAN_IRIAN = 11
    INDONESIAN_SOUTHERN = 12
    INDIA_ZONE_0 = 13
    INDIA_ZONE_IA = 14
    INDIA_ZONE_IB = 15
    INDIA_ZONE_IIA = 16
    INDIA_ZONE_IIB = 17
    INDIA_ZONE_IIIA = 18
    INDIA_ZONE_IIIB = 19
    INDIA_ZONE_IVA = 20
    INDIA_ZONE_IVB = 21
    IRISH_TRANSVERSE = 22
    IRISH_GRID = 23
    LORAN = 24
    MAIDENHEAD_GRID = 25
    MGRS_GRID = 26
    NEW_ZEALAND_GRID = 27
    NEW_ZEALAND_TRANSVERSE = 28
    QATAR_GRID = 29
    MODIFIED_SWEDISH_GRID = 30
    SWEDISH_GRID = 31
    SOUTH_AFRICAN_GRID = 32
    SWISS_GRID = 33
    TAIWAN_GRID = 34
    UNITED_STATES_GRID = 35
    UTM_UPS_GRID = 36
    WEST_MALAYAN = 37
    BORNEO_RSO = 38
    ESTONIAN_GRID = 39
    LATVIAN_GRID = 40
    SWEDISH_REF_99_GRID = 41


class SwitchType(Enum):
    OFF = 0
    ON = 1
    AUTO = 2


class Sport(Enum):
    GENERIC = 0
    RUNNING = 1
    CYCLING = 2
    TRANSITION = 3
    FITNESS_EQUIPMENT = 4
    SWIMMING = 5
    BASKETBALL = 6
    SOCCER = 7
    TENNIS = 8
    AMERICAN_FOOTBALL = 9
    TRAINING = 10
    WALKING = 11
    CROSS_COUNTRY_SKIING = 12
    ALPINE_SKIING = 13
    SNOWBOARDING = 14
    ROWING = 15
    MOUNTAINEERING = 16
    HIKING = 17
    MULTISPORT = 18
    PADDLING = 19
    FLYING = 20
    E_BIKING = 21
    MOTORCYCLING = 22
    BOATING = 23
    DRIVING = 24
    GOLF = 25
    HANG_GLIDING = 26
    HORSEBACK_RIDING = 27
    HUNTING = 28
    FISHING = 29
    INLINE_SKATING = 30
    ROCK_CLIMBING = 31
    SAILING = 32
    ICE_SKATING = 33
    SKY_DIVING = 34
    SNOWSHOEING = 35
    SNOWMOBILING = 36
    STAND_UP_PADDLEBOARDING = 37
    SURFING = 38
    WAKEBOARDING = 39
    WATER_SKIING = 40
    KAYAKING = 41
    RAFTING = 42
    WINDSURFING = 43
    KITESURFING = 44
    TACTICAL = 45
    JUMPMASTER = 46
    BOXING = 47
    FLOOR_CLIMBING = 48
    DIVING = 53
    ALL = 254


class SportBits0(Enum):
    GENERIC = 1
    RUNNING = 2
    CYCLING = 4
    TRANSITION = 8
    FITNESS_EQUIPMENT = 16
    SWIMMING = 32
    BASKETBALL = 64
    SOCCER = 128


class SportBits1(Enum):
    TENNIS = 1
    AMERICAN_FOOTBALL = 2
    TRAINING = 4
    WALKING = 8
    CROSS_COUNTRY_SKIING = 16
    ALPINE_SKIING = 32
    SNOWBOARDING = 64
    ROWING = 128


class SportBits2(Enum):
    MOUNTAINEERING = 1
    HIKING = 2
    MULTISPORT = 4
    PADDLING = 8
    FLYING = 16
    E_BIKING = 32
    MOTORCYCLING = 64
    BOATING = 128


class SportBits3(Enum):
    DRIVING = 1
    GOLF = 2
    HANG_GLIDING = 4
    HORSEBACK_RIDING = 8
    HUNTING = 16
    FISHING = 32
    INLINE_SKATING = 64
    ROCK_CLIMBING = 128


class SportBits4(Enum):
    SAILING = 1
    ICE_SKATING = 2
    SKY_DIVING = 4
    SNOWSHOEING = 8
    SNOWMOBILING = 16
    STAND_UP_PADDLEBOARDING = 32
    SURFING = 64
    WAKEBOARDING = 128


class SportBits5(Enum):
    WATER_SKIING = 1
    KAYAKING = 2
    RAFTING = 4
    WINDSURFING = 8
    KITESURFING = 16
    TACTICAL = 32
    JUMPMASTER = 64
    BOXING = 128


class SportBits6(Enum):
    FLOOR_CLIMBING = 1


class SubSport(Enum):
    GENERIC = 0
    TREADMILL = 1
    STREET = 2
    TRAIL = 3
    TRACK = 4
    SPIN = 5
    INDOOR_CYCLING = 6
    ROAD = 7
    MOUNTAIN = 8
    DOWNHILL = 9
    RECUMBENT = 10
    CYCLOCROSS = 11
    HAND_CYCLING = 12
    TRACK_CYCLING = 13
    INDOOR_ROWING = 14
    ELLIPTICAL = 15
    STAIR_CLIMBING = 16
    LAP_SWIMMING = 17
    OPEN_WATER = 18
    FLEXIBILITY_TRAINING = 19
    STRENGTH_TRAINING = 20
    WARM_UP = 21
    MATCH = 22
    EXERCISE = 23
    CHALLENGE = 24
    INDOOR_SKIING = 25
    CARDIO_TRAINING = 26
    INDOOR_WALKING = 27
    E_BIKE_FITNESS = 28
    BMX = 29
    CASUAL_WALKING = 30
    SPEED_WALKING = 31
    BIKE_TO_RUN_TRANSITION = 32
    RUN_TO_BIKE_TRANSITION = 33
    SWIM_TO_BIKE_TRANSITION = 34
    ATV = 35
    MOTOCROSS = 36
    BACKCOUNTRY = 37
    RESORT = 38
    RC_DRONE = 39
    WINGSUIT = 40
    WHITEWATER = 41
    SKATE_SKIING = 42
    YOGA = 43
    PILATES = 44
    INDOOR_RUNNING = 45
    GRAVEL_CYCLING = 46
    E_BIKE_MOUNTAIN = 47
    COMMUTING = 48
    MIXED_SURFACE = 49
    NAVIGATE = 50
    TRACK_ME = 51
    MAP = 52
    SINGLE_GAS_DIVING = 53
    MULTI_GAS_DIVING = 54
    GAUGE_DIVING = 55
    APNEA_DIVING = 56
    APNEA_HUNTING = 57
    VIRTUAL_ACTIVITY = 58
    OBSTACLE = 59
    SAIL_RACE = 65
    ALL = 254


class SportEvent(Enum):
    UNCATEGORIZED = 0
    GEOCACHING = 1
    FITNESS = 2
    RECREATION = 3
    RACE = 4
    SPECIAL_EVENT = 5
    TRAINING = 6
    TRANSPORTATION = 7
    TOURING = 8


class Activity(Enum):
    MANUAL = 0
    AUTO_MULTI_SPORT = 1


class Intensity(Enum):
    ACTIVE = 0
    REST = 1
    WARMUP = 2
    COOLDOWN = 3
    RECOVERY = 4
    INTERVAL = 5
    OTHER = 6


class SessionTrigger(Enum):
    ACTIVITY_END = 0
    MANUAL = 1
    AUTO_MULTI_SPORT = 2
    FITNESS_EQUIPMENT = 3


class AutolapTrigger(Enum):
    TIME = 0
    DISTANCE = 1
    POSITION_START = 2
    POSITION_LAP = 3
    POSITION_WAYPOINT = 4
    POSITION_MARKED = 5
    OFF = 6


class LapTrigger(Enum):
    MANUAL = 0
    TIME = 1
    DISTANCE = 2
    POSITION_START = 3
    POSITION_LAP = 4
    POSITION_WAYPOINT = 5
    POSITION_MARKED = 6
    SESSION_END = 7
    FITNESS_EQUIPMENT = 8


class TimeMode(Enum):
    HOUR12 = 0
    HOUR24 = 1
    MILITARY = 2
    HOUR_12_WITH_SECONDS = 3
    HOUR_24_WITH_SECONDS = 4
    UTC = 5


class BacklightMode(Enum):
    OFF = 0
    MANUAL = 1
    KEY_AND_MESSAGES = 2
    AUTO_BRIGHTNESS = 3
    SMART_NOTIFICATIONS = 4
    KEY_AND_MESSAGES_NIGHT = 5
    KEY_AND_MESSAGES_AND_SMART_NOTIFICATIONS = 6


class DateMode(Enum):
    DAY_MONTH = 0
    MONTH_DAY = 1


class BacklightTimeout(Enum):
    INFINITE = 0


class Event(Enum):
    TIMER = 0
    WORKOUT = 3
    WORKOUT_STEP = 4
    POWER_DOWN = 5
    POWER_UP = 6
    OFF_COURSE = 7
    SESSION = 8
    LAP = 9
    COURSE_POINT = 10
    BATTERY = 11
    VIRTUAL_PARTNER_PACE = 12
    HR_HIGH_ALERT = 13
    HR_LOW_ALERT = 14
    SPEED_HIGH_ALERT = 15
    SPEED_LOW_ALERT = 16
    CAD_HIGH_ALERT = 17
    CAD_LOW_ALERT = 18
    POWER_HIGH_ALERT = 19
    POWER_LOW_ALERT = 20
    RECOVERY_HR = 21
    BATTERY_LOW = 22
    TIME_DURATION_ALERT = 23
    DISTANCE_DURATION_ALERT = 24
    CALORIE_DURATION_ALERT = 25
    ACTIVITY = 26
    FITNESS_EQUIPMENT = 27
    LENGTH = 28
    USER_MARKER = 32
    SPORT_POINT = 33
    CALIBRATION = 36
    FRONT_GEAR_CHANGE = 42
    REAR_GEAR_CHANGE = 43
    RIDER_POSITION_CHANGE = 44
    ELEV_HIGH_ALERT = 45
    ELEV_LOW_ALERT = 46
    COMM_TIMEOUT = 47
    RADAR_THREAT_ALERT = 75


class EventType(Enum):
    START = 0
    STOP = 1
    CONSECUTIVE_DEPRECIATED = 2
    MARKER = 3
    STOP_ALL = 4
    BEGIN_DEPRECIATED = 5
    END_DEPRECIATED = 6
    END_ALL_DEPRECIATED = 7
    STOP_DISABLE = 8
    STOP_DISABLE_ALL = 9


class TimerTrigger(Enum):
    MANUAL = 0
    AUTO = 1
    FITNESS_EQUIPMENT = 2


class FitnessEquipmentState(Enum):
    READY = 0
    IN_USE = 1
    PAUSED = 2
    UNKNOWN = 3


class Tone(Enum):
    OFF = 0
    TONE = 1
    VIBRATE = 2
    TONE_AND_VIBRATE = 3


class Autoscroll(Enum):
    NONE = 0
    SLOW = 1
    MEDIUM = 2
    FAST = 3


class ActivityClass(Enum):
    LEVEL = 127
    LEVEL_MAX = 100
    ATHLETE = 128


class HrZoneCalc(Enum):
    CUSTOM = 0
    PERCENT_MAX_HR = 1
    PERCENT_HRR = 2


class PwrZoneCalc(Enum):
    CUSTOM = 0
    PERCENT_FTP = 1


class WorkoutStepDuration(Enum):
    TIME = 0
    DISTANCE = 1
    HR_LESS_THAN = 2
    HR_GREATER_THAN = 3
    CALORIES = 4
    OPEN = 5
    REPEAT_UNTIL_STEPS_CMPLT = 6
    REPEAT_UNTIL_TIME = 7
    REPEAT_UNTIL_DISTANCE = 8
    REPEAT_UNTIL_CALORIES = 9
    REPEAT_UNTIL_HR_LESS_THAN = 10
    REPEAT_UNTIL_HR_GREATER_THAN = 11
    REPEAT_UNTIL_POWER_LESS_THAN = 12
    REPEAT_UNTIL_POWER_GREATER_THAN = 13
    POWER_LESS_THAN = 14
    POWER_GREATER_THAN = 15
    TRAINING_PEAKS_TSS = 16
    REPEAT_UNTIL_POWER_LAST_LAP_LESS_THAN = 17
    REPEAT_UNTIL_MAX_POWER_LAST_LAP_LESS_THAN = 18
    POWER_3S_LESS_THAN = 19
    POWER_10S_LESS_THAN = 20
    POWER_30S_LESS_THAN = 21
    POWER_3S_GREATER_THAN = 22
    POWER_10S_GREATER_THAN = 23
    POWER_30S_GREATER_THAN = 24
    POWER_LAP_LESS_THAN = 25
    POWER_LAP_GREATER_THAN = 26
    REPEAT_UNTIL_TRAINING_PEAKS_TSS = 27
    REPETITION_TIME = 28
    REPS = 29
    TIME_ONLY = 31


class WorkoutStepTarget(Enum):
    SPEED = 0
    HEART_RATE = 1
    OPEN = 2
    CADENCE = 3
    POWER = 4
    GRADE = 5
    RESISTANCE = 6
    POWER_3S = 7
    POWER_10S = 8
    POWER_30S = 9
    POWER_LAP = 10
    SWIM_STROKE = 11
    SPEED_LAP = 12
    HEART_RATE_LAP = 13


class Goal(Enum):
    TIME = 0
    DISTANCE = 1
    CALORIES = 2
    FREQUENCY = 3
    STEPS = 4
    ASCENT = 5
    ACTIVE_MINUTES = 6


class GoalRecurrence(Enum):
    OFF = 0
    DAILY = 1
    WEEKLY = 2
    MONTHLY = 3
    YEARLY = 4
    CUSTOM = 5


class GoalSource(Enum):
    AUTO = 0
    COMMUNITY = 1
    USER = 2


class Schedule(Enum):
    WORKOUT = 0
    COURSE = 1


class CoursePoint(Enum):
    GENERIC = 0
    SUMMIT = 1
    VALLEY = 2
    WATER = 3
    FOOD = 4
    DANGER = 5
    LEFT = 6
    RIGHT = 7
    STRAIGHT = 8
    FIRST_AID = 9
    FOURTH_CATEGORY = 10
    THIRD_CATEGORY = 11
    SECOND_CATEGORY = 12
    FIRST_CATEGORY = 13
    HORS_CATEGORY = 14
    SPRINT = 15
    LEFT_FORK = 16
    RIGHT_FORK = 17
    MIDDLE_FORK = 18
    SLIGHT_LEFT = 19
    SHARP_LEFT = 20
    SLIGHT_RIGHT = 21
    SHARP_RIGHT = 22
    U_TURN = 23
    SEGMENT_START = 24
    SEGMENT_END = 25


class Manufacturer(Enum):
    GARMIN = 1
    GARMIN_FR405_ANTFS = 2
    ZEPHYR = 3
    DAYTON = 4
    IDT = 5
    SRM = 6
    QUARQ = 7
    IBIKE = 8
    SARIS = 9
    SPARK_HK = 10
    TANITA = 11
    ECHOWELL = 12
    DYNASTREAM_OEM = 13
    NAUTILUS = 14
    DYNASTREAM = 15
    TIMEX = 16
    METRIGEAR = 17
    XELIC = 18
    BEURER = 19
    CARDIOSPORT = 20
    A_AND_D = 21
    HMM = 22
    SUUNTO = 23
    THITA_ELEKTRONIK = 24
    GPULSE = 25
    CLEAN_MOBILE = 26
    PEDAL_BRAIN = 27
    PEAKSWARE = 28
    SAXONAR = 29
    LEMOND_FITNESS = 30
    DEXCOM = 31
    WAHOO_FITNESS = 32
    OCTANE_FITNESS = 33
    ARCHINOETICS = 34
    THE_HURT_BOX = 35
    CITIZEN_SYSTEMS = 36
    MAGELLAN = 37
    OSYNCE = 38
    HOLUX = 39
    CONCEPT2 = 40
    SHIMANO = 41
    ONE_GIANT_LEAP = 42
    ACE_SENSOR = 43
    BRIM_BROTHERS = 44
    XPLOVA = 45
    PERCEPTION_DIGITAL = 46
    BF1SYSTEMS = 47
    PIONEER = 48
    SPANTEC = 49
    METALOGICS = 50
    N4IIIIS = 51
    SEIKO_EPSON = 52
    SEIKO_EPSON_OEM = 53
    IFOR_POWELL = 54
    MAXWELL_GUIDER = 55
    STAR_TRAC = 56
    BREAKAWAY = 57
    ALATECH_TECHNOLOGY_LTD = 58
    MIO_TECHNOLOGY_EUROPE = 59
    ROTOR = 60
    GEONAUTE = 61
    ID_BIKE = 62
    SPECIALIZED = 63
    WTEK = 64
    PHYSICAL_ENTERPRISES = 65
    NORTH_POLE_ENGINEERING = 66
    BKOOL = 67
    CATEYE = 68
    STAGES_CYCLING = 69
    SIGMASPORT = 70
    TOMTOM = 71
    PERIPEDAL = 72
    WATTBIKE = 73
    MOXY = 76
    CICLOSPORT = 77
    POWERBAHN = 78
    ACORN_PROJECTS_APS = 79
    LIFEBEAM = 80
    BONTRAGER = 81
    WELLGO = 82
    SCOSCHE = 83
    MAGURA = 84
    WOODWAY = 85
    ELITE = 86
    NIELSEN_KELLERMAN = 87
    DK_CITY = 88
    TACX = 89
    DIRECTION_TECHNOLOGY = 90
    MAGTONIC = 91
    N1PARTCARBON = 92
    INSIDE_RIDE_TECHNOLOGIES = 93
    SOUND_OF_MOTION = 94
    STRYD = 95
    ICG = 96
    MI_PULSE = 97
    BSX_ATHLETICS = 98
    LOOK = 99
    CAMPAGNOLO_SRL = 100
    BODY_BIKE_SMART = 101
    PRAXISWORKS = 102
    LIMITS_TECHNOLOGY = 103
    TOPACTION_TECHNOLOGY = 104
    COSINUSS = 105
    FITCARE = 106
    MAGENE = 107
    GIANT_MANUFACTURING_CO = 108
    TIGRASPORT = 109
    SALUTRON = 110
    TECHNOGYM = 111
    BRYTON_SENSORS = 112
    LATITUDE_LIMITED = 113
    SOARING_TECHNOLOGY = 114
    IGPSPORT = 115
    THINKRIDER = 116
    GOPHER_SPORT = 117
    WATERROWER = 118
    ORANGETHEORY = 119
    INPEAK = 120
    KINETIC = 121
    JOHNSON_HEALTH_TECH = 122
    POLAR_ELECTRO = 123
    SEESENSE = 124
    NCI_TECHNOLOGY = 125
    IQSQUARE = 126
    LEOMO = 127
    IFIT_COM = 128
    COROS_BYTE = 129
    VERSA_DESIGN = 130
    CHILEAF = 131
    CYCPLUS = 132
    GRAVAA_BYTE = 133
    SIGEYI = 134
    COOSPO = 135
    DEVELOPMENT = 255
    HEALTHANDLIFE = 257
    LEZYNE = 258
    SCRIBE_LABS = 259
    ZWIFT = 260
    WATTEAM = 261
    RECON = 262
    FAVERO_ELECTRONICS = 263
    DYNOVELO = 264
    STRAVA = 265
    PRECOR = 266
    BRYTON = 267
    SRAM = 268
    NAVMAN = 269
    COBI = 270
    SPIVI = 271
    MIO_MAGELLAN = 272
    EVESPORTS = 273
    SENSITIVUS_GAUGE = 274
    PODOON = 275
    LIFE_TIME_FITNESS = 276
    FALCO_E_MOTORS = 277
    MINOURA = 278
    CYCLIQ = 279
    LUXOTTICA = 280
    TRAINER_ROAD = 281
    THE_SUFFERFEST = 282
    FULLSPEEDAHEAD = 283
    VIRTUALTRAINING = 284
    FEEDBACKSPORTS = 285
    OMATA = 286
    VDO = 287
    MAGNETICDAYS = 288
    HAMMERHEAD = 289
    KINETIC_BY_KURT = 290
    SHAPELOG = 291
    DABUZIDUO = 292
    JETBLACK = 293
    COROS = 294
    VIRTUGO = 295
    VELOSENSE = 296
    CYCLIGENTINC = 297
    TRAILFORKS = 298
    MAHLE_EBIKEMOTION = 299
    NURVV = 300
    MICROPROGRAM = 301
    ZONE5CLOUD = 302
    GREENTEG = 303
    YAMAHA_MOTORS = 304
    WHOOP = 305
    GRAVAA = 306
    ONELAP = 307
    MONARK_EXERCISE = 308
    FORM = 309
    DECATHLON = 310
    SYNCROS = 311
    ACTIGRAPHCORP = 5759


class GarminProduct(Enum):
    HRM1 = 1
    AXH01 = 2
    AXB01 = 3
    AXB02 = 4
    HRM2SS = 5
    DSI_ALF02 = 6
    HRM3SS = 7
    HRM_RUN_SINGLE_BYTE_PRODUCT_ID = 8
    BSM = 9
    BCM = 10
    AXS01 = 11
    HRM_TRI_SINGLE_BYTE_PRODUCT_ID = 12
    HRM4_RUN_SINGLE_BYTE_PRODUCT_ID = 13
    FR225_SINGLE_BYTE_PRODUCT_ID = 14
    GEN3_BSM_SINGLE_BYTE_PRODUCT_ID = 15
    GEN3_BCM_SINGLE_BYTE_PRODUCT_ID = 16
    FR301_CHINA = 473
    FR301_JAPAN = 474
    FR301_KOREA = 475
    FR301_TAIWAN = 494
    FR405 = 717
    FR50 = 782
    FR405_JAPAN = 987
    FR60 = 988
    DSI_ALF01 = 1011
    FR310XT = 1018
    EDGE500 = 1036
    FR110 = 1124
    EDGE800 = 1169
    EDGE500_TAIWAN = 1199
    EDGE500_JAPAN = 1213
    CHIRP = 1253
    FR110_JAPAN = 1274
    EDGE200 = 1325
    FR910XT = 1328
    EDGE800_TAIWAN = 1333
    EDGE800_JAPAN = 1334
    ALF04 = 1341
    FR610 = 1345
    FR210_JAPAN = 1360
    VECTOR_SS = 1380
    VECTOR_CP = 1381
    EDGE800_CHINA = 1386
    EDGE500_CHINA = 1387
    APPROACH_G10 = 1405
    FR610_JAPAN = 1410
    EDGE500_KOREA = 1422
    FR70 = 1436
    FR310XT_4T = 1446
    AMX = 1461
    FR10 = 1482
    EDGE800_KOREA = 1497
    SWIM = 1499
    FR910XT_CHINA = 1537
    FENIX = 1551
    EDGE200_TAIWAN = 1555
    EDGE510 = 1561
    EDGE810 = 1567
    TEMPE = 1570
    FR910XT_JAPAN = 1600
    FR620 = 1623
    FR220 = 1632
    FR910XT_KOREA = 1664
    FR10_JAPAN = 1688
    EDGE810_JAPAN = 1721
    VIRB_ELITE = 1735
    EDGE_TOURING = 1736
    EDGE510_JAPAN = 1742
    HRM_TRI = 1743
    HRM_RUN = 1752
    FR920XT = 1765
    EDGE510_ASIA = 1821
    EDGE810_CHINA = 1822
    EDGE810_TAIWAN = 1823
    EDGE1000 = 1836
    VIVO_FIT = 1837
    VIRB_REMOTE = 1853
    VIVO_KI = 1885
    FR15 = 1903
    VIVO_ACTIVE = 1907
    EDGE510_KOREA = 1918
    FR620_JAPAN = 1928
    FR620_CHINA = 1929
    FR220_JAPAN = 1930
    FR220_CHINA = 1931
    APPROACH_S6 = 1936
    VIVO_SMART = 1956
    FENIX2 = 1967
    EPIX = 1988
    FENIX3 = 2050
    EDGE1000_TAIWAN = 2052
    EDGE1000_JAPAN = 2053
    FR15_JAPAN = 2061
    EDGE520 = 2067
    EDGE1000_CHINA = 2070
    FR620_RUSSIA = 2072
    FR220_RUSSIA = 2073
    VECTOR_S = 2079
    EDGE1000_KOREA = 2100
    FR920XT_TAIWAN = 2130
    FR920XT_CHINA = 2131
    FR920XT_JAPAN = 2132
    VIRBX = 2134
    VIVO_SMART_APAC = 2135
    ETREX_TOUCH = 2140
    EDGE25 = 2147
    FR25 = 2148
    VIVO_FIT2 = 2150
    FR225 = 2153
    FR630 = 2156
    FR230 = 2157
    FR735XT = 2158
    VIVO_ACTIVE_APAC = 2160
    VECTOR_2 = 2161
    VECTOR_2S = 2162
    VIRBXE = 2172
    FR620_TAIWAN = 2173
    FR220_TAIWAN = 2174
    TRUSWING = 2175
    D2AIRVENU = 2187
    FENIX3_CHINA = 2188
    FENIX3_TWN = 2189
    VARIA_HEADLIGHT = 2192
    VARIA_TAILLIGHT_OLD = 2193
    EDGE_EXPLORE_1000 = 2204
    FR225_ASIA = 2219
    VARIA_RADAR_TAILLIGHT = 2225
    VARIA_RADAR_DISPLAY = 2226
    EDGE20 = 2238
    EDGE520_ASIA = 2260
    EDGE520_JAPAN = 2261
    D2_BRAVO = 2262
    APPROACH_S20 = 2266
    VIVO_SMART2 = 2271
    EDGE1000_THAI = 2274
    VARIA_REMOTE = 2276
    EDGE25_ASIA = 2288
    EDGE25_JPN = 2289
    EDGE20_ASIA = 2290
    APPROACH_X40 = 2292
    FENIX3_JAPAN = 2293
    VIVO_SMART_EMEA = 2294
    FR630_ASIA = 2310
    FR630_JPN = 2311
    FR230_JPN = 2313
    HRM4_RUN = 2327
    EPIX_JAPAN = 2332
    VIVO_ACTIVE_HR = 2337
    VIVO_SMART_GPS_HR = 2347
    VIVO_SMART_HR = 2348
    VIVO_SMART_HR_ASIA = 2361
    VIVO_SMART_GPS_HR_ASIA = 2362
    VIVO_MOVE = 2368
    VARIA_TAILLIGHT = 2379
    FR235_ASIA = 2396
    FR235_JAPAN = 2397
    VARIA_VISION = 2398
    VIVO_FIT3 = 2406
    FENIX3_KOREA = 2407
    FENIX3_SEA = 2408
    FENIX3_HR = 2413
    VIRB_ULTRA_30 = 2417
    INDEX_SMART_SCALE = 2429
    FR235 = 2431
    FENIX3_CHRONOS = 2432
    OREGON7XX = 2441
    RINO7XX = 2444
    EPIX_KOREA = 2457
    FENIX3_HR_CHN = 2473
    FENIX3_HR_TWN = 2474
    FENIX3_HR_JPN = 2475
    FENIX3_HR_SEA = 2476
    FENIX3_HR_KOR = 2477
    NAUTIX = 2496
    VIVO_ACTIVE_HR_APAC = 2497
    OREGON7XX_WW = 2512
    EDGE_820 = 2530
    EDGE_EXPLORE_820 = 2531
    FR735XT_APAC = 2533
    FR735XT_JAPAN = 2534
    FENIX5S = 2544
    D2_BRAVO_TITANIUM = 2547
    VARIA_UT800 = 2567
    RUNNING_DYNAMICS_POD = 2593
    EDGE_820_CHINA = 2599
    EDGE_820_JAPAN = 2600
    FENIX5X = 2604
    VIVO_FIT_JR = 2606
    VIVO_SMART3 = 2622
    VIVO_SPORT = 2623
    EDGE_820_TAIWAN = 2628
    EDGE_820_KOREA = 2629
    EDGE_820_SEA = 2630
    FR35_HEBREW = 2650
    APPROACH_S60 = 2656
    FR35_APAC = 2667
    FR35_JAPAN = 2668
    FENIX3_CHRONOS_ASIA = 2675
    VIRB_360 = 2687
    FR935 = 2691
    FENIX5 = 2697
    VIVOACTIVE3 = 2700
    FR235_CHINA_NFC = 2733
    FORETREX_601_701 = 2769
    VIVO_MOVE_HR = 2772
    EDGE_1030 = 2713
    VECTOR_3 = 2787
    FENIX5_ASIA = 2796
    FENIX5S_ASIA = 2797
    FENIX5X_ASIA = 2798
    APPROACH_Z80 = 2806
    FR35_KOREA = 2814
    D2CHARLIE = 2819
    VIVO_SMART3_APAC = 2831
    VIVO_SPORT_APAC = 2832
    FR935_ASIA = 2833
    DESCENT = 2859
    VIVO_FIT4 = 2878
    FR645 = 2886
    FR645M = 2888
    FR30 = 2891
    FENIX5S_PLUS = 2900
    EDGE_130 = 2909
    EDGE_1030_ASIA = 2924
    VIVOSMART_4 = 2927
    VIVO_MOVE_HR_ASIA = 2945
    APPROACH_X10 = 2962
    FR30_ASIA = 2977
    VIVOACTIVE3M_W = 2988
    FR645_ASIA = 3003
    FR645M_ASIA = 3004
    EDGE_EXPLORE = 3011
    GPSMAP66 = 3028
    APPROACH_S10 = 3049
    VIVOACTIVE3M_L = 3066
    APPROACH_G80 = 3085
    EDGE_130_ASIA = 3092
    EDGE_1030_BONTRAGER = 3095
    FENIX5_PLUS = 3110
    FENIX5X_PLUS = 3111
    EDGE_520_PLUS = 3112
    FR945 = 3113
    EDGE_530 = 3121
    EDGE_830 = 3122
    INSTINCT_ESPORTS = 3126
    FENIX5S_PLUS_APAC = 3134
    FENIX5X_PLUS_APAC = 3135
    EDGE_520_PLUS_APAC = 3142
    FR235L_ASIA = 3144
    FR245_ASIA = 3145
    VIVO_ACTIVE3M_APAC = 3163
    GEN3_BSM = 3192
    GEN3_BCM = 3193
    VIVO_SMART4_ASIA = 3218
    VIVOACTIVE4_SMALL = 3224
    VIVOACTIVE4_LARGE = 3225
    VENU = 3226
    MARQ_DRIVER = 3246
    MARQ_AVIATOR = 3247
    MARQ_CAPTAIN = 3248
    MARQ_COMMANDER = 3249
    MARQ_EXPEDITION = 3250
    MARQ_ATHLETE = 3251
    DESCENT_MK2 = 3258
    GPSMAP66I = 3284
    FENIX6_S_SPORT = 3287
    FENIX6_S = 3288
    FENIX6_SPORT = 3289
    FENIX6 = 3290
    FENIX6X = 3291
    HRM_DUAL = 3299
    HRM_PRO = 3300
    VIVO_MOVE3_PREMIUM = 3308
    APPROACH_S40 = 3314
    FR245M_ASIA = 3321
    EDGE_530_APAC = 3349
    EDGE_830_APAC = 3350
    VIVO_MOVE3 = 3378
    VIVO_ACTIVE4_SMALL_ASIA = 3387
    VIVO_ACTIVE4_LARGE_ASIA = 3388
    VIVO_ACTIVE4_OLED_ASIA = 3389
    SWIM2 = 3405
    MARQ_DRIVER_ASIA = 3420
    MARQ_AVIATOR_ASIA = 3421
    VIVO_MOVE3_ASIA = 3422
    FR945_ASIA = 3441
    VIVO_ACTIVE3T_CHN = 3446
    MARQ_CAPTAIN_ASIA = 3448
    MARQ_COMMANDER_ASIA = 3449
    MARQ_EXPEDITION_ASIA = 3450
    MARQ_ATHLETE_ASIA = 3451
    FR45_ASIA = 3469
    VIVOACTIVE3_DAIMLER = 3473
    LEGACY_REY = 3498
    LEGACY_DARTH_VADER = 3499
    LEGACY_CAPTAIN_MARVEL = 3500
    LEGACY_FIRST_AVENGER = 3501
    FENIX6S_SPORT_ASIA = 3512
    FENIX6S_ASIA = 3513
    FENIX6_SPORT_ASIA = 3514
    FENIX6_ASIA = 3515
    FENIX6X_ASIA = 3516
    LEGACY_CAPTAIN_MARVEL_ASIA = 3535
    LEGACY_FIRST_AVENGER_ASIA = 3536
    LEGACY_REY_ASIA = 3537
    LEGACY_DARTH_VADER_ASIA = 3538
    DESCENT_MK2S = 3542
    EDGE_130_PLUS = 3558
    EDGE_1030_PLUS = 3570
    RALLY_200 = 3578
    FR745 = 3589
    VENUSQ = 3600
    LILY = 3615
    MARQ_ADVENTURER = 3624
    ENDURO = 3638
    MARQ_ADVENTURER_ASIA = 3648
    SWIM2_APAC = 3639
    DESCENT_MK2_ASIA = 3702
    VENU2 = 3703
    VENU2S = 3704
    VENU_DAIMLER_ASIA = 3737
    MARQ_GOLFER = 3739
    VENU_DAIMLER = 3740
    FR745_ASIA = 3794
    LILY_ASIA = 3809
    EDGE_1030_PLUS_ASIA = 3812
    EDGE_130_PLUS_ASIA = 3813
    APPROACH_S12 = 3823
    ENDURO_ASIA = 3872
    VENUSQ_ASIA = 3837
    MARQ_GOLFER_ASIA = 3850
    APPROACH_G12 = 3927
    DESCENT_MK2S_ASIA = 3930
    APPROACH_S42 = 3934
    VENU2S_ASIA = 3949
    VENU2_ASIA = 3950
    APPROACH_S12_ASIA = 3986
    APPROACH_G12_ASIA = 4001
    APPROACH_S42_ASIA = 4002
    SDM4 = 10007
    EDGE_REMOTE = 10014
    TACX_TRAINING_APP_WIN = 20533
    TACX_TRAINING_APP_MAC = 20534
    TRAINING_CENTER = 20119
    TACX_TRAINING_APP_ANDROID = 30045
    TACX_TRAINING_APP_IOS = 30046
    TACX_TRAINING_APP_LEGACY = 30047
    CONNECTIQ_SIMULATOR = 65531
    ANDROID_ANTPLUS_PLUGIN = 65532
    CONNECT = 65534


class AntplusDeviceType(Enum):
    ANTFS = 1
    BIKE_POWER = 11
    ENVIRONMENT_SENSOR_LEGACY = 12
    MULTI_SPORT_SPEED_DISTANCE = 15
    CONTROL = 16
    FITNESS_EQUIPMENT = 17
    BLOOD_PRESSURE = 18
    GEOCACHE_NODE = 19
    LIGHT_ELECTRIC_VEHICLE = 20
    ENV_SENSOR = 25
    RACQUET = 26
    CONTROL_HUB = 27
    MUSCLE_OXYGEN = 31
    BIKE_LIGHT_MAIN = 35
    BIKE_LIGHT_SHARED = 36
    EXD = 38
    BIKE_RADAR = 40
    BIKE_AERO = 46
    WEIGHT_SCALE = 119
    HEART_RATE = 120
    BIKE_SPEED_CADENCE = 121
    BIKE_CADENCE = 122
    BIKE_SPEED = 123
    STRIDE_SPEED_DISTANCE = 124


class AntNetwork(Enum):
    PUBLIC = 0
    ANTPLUS = 1
    ANTFS = 2
    PRIVATE = 3


class WorkoutCapabilities(Enum):
    INTERVAL = 1
    CUSTOM = 2
    FITNESS_EQUIPMENT = 4
    FIRSTBEAT = 8
    NEW_LEAF = 16
    TCX = 32
    SPEED = 128
    HEART_RATE = 256
    DISTANCE = 512
    CADENCE = 1024
    POWER = 2048
    GRADE = 4096
    RESISTANCE = 8192
    PROTECTED = 16384


class BatteryStatus(Enum):
    NEW = 1
    GOOD = 2
    OK = 3
    LOW = 4
    CRITICAL = 5
    CHARGING = 6
    UNKNOWN = 7


class HrType(Enum):
    NORMAL = 0
    IRREGULAR = 1


class CourseCapabilities(Enum):
    PROCESSED = 1
    VALID = 2
    TIME = 4
    DISTANCE = 8
    POSITION = 16
    HEART_RATE = 32
    POWER = 64
    CADENCE = 128
    TRAINING = 256
    NAVIGATION = 512
    BIKEWAY = 1024


class Weight(Enum):
    CALCULATING = 65534


class WorkoutHr(Enum):
    BPM_OFFSET = 100


class WorkoutPower(Enum):
    WATTS_OFFSET = 1000


class BpStatus(Enum):
    NO_ERROR = 0
    ERROR_INCOMPLETE_DATA = 1
    ERROR_NO_MEASUREMENT = 2
    ERROR_DATA_OUT_OF_RANGE = 3
    ERROR_IRREGULAR_HEART_RATE = 4


class UserLocalId(Enum):
    LOCAL_MIN = 0
    LOCAL_MAX = 15
    STATIONARY_MIN = 16
    STATIONARY_MAX = 255
    PORTABLE_MIN = 256
    PORTABLE_MAX = 65534


class SwimStroke(Enum):
    FREESTYLE = 0
    BACKSTROKE = 1
    BREASTSTROKE = 2
    BUTTERFLY = 3
    DRILL = 4
    MIXED = 5
    IM = 6


class ActivityType(Enum):
    GENERIC = 0
    RUNNING = 1
    CYCLING = 2
    TRANSITION = 3
    FITNESS_EQUIPMENT = 4
    SWIMMING = 5
    WALKING = 6
    SEDENTARY = 8
    ALL = 254


class ActivitySubtype(Enum):
    GENERIC = 0
    TREADMILL = 1
    STREET = 2
    TRAIL = 3
    TRACK = 4
    SPIN = 5
    INDOOR_CYCLING = 6
    ROAD = 7
    MOUNTAIN = 8
    DOWNHILL = 9
    RECUMBENT = 10
    CYCLOCROSS = 11
    HAND_CYCLING = 12
    TRACK_CYCLING = 13
    INDOOR_ROWING = 14
    ELLIPTICAL = 15
    STAIR_CLIMBING = 16
    LAP_SWIMMING = 17
    OPEN_WATER = 18
    ALL = 254


class ActivityLevel(Enum):
    LOW = 0
    MEDIUM = 1
    HIGH = 2


class Side(Enum):
    RIGHT = 0
    LEFT = 1


class LeftRightBalance(Enum):
    MASK = 127
    RIGHT = 128


class LeftRightBalance100(Enum):
    MASK = 16383
    RIGHT = 32768


class LengthType(Enum):
    IDLE = 0
    ACTIVE = 1


class DayOfWeek(Enum):
    SUNDAY = 0
    MONDAY = 1
    TUESDAY = 2
    WEDNESDAY = 3
    THURSDAY = 4
    FRIDAY = 5
    SATURDAY = 6


class ConnectivityCapabilities(Enum):
    BLUETOOTH = 1
    BLUETOOTH_LE = 2
    ANT = 4
    ACTIVITY_UPLOAD = 8
    COURSE_DOWNLOAD = 16
    WORKOUT_DOWNLOAD = 32
    LIVE_TRACK = 64
    WEATHER_CONDITIONS = 128
    WEATHER_ALERTS = 256
    GPS_EPHEMERIS_DOWNLOAD = 512
    EXPLICIT_ARCHIVE = 1024
    SETUP_INCOMPLETE = 2048
    CONTINUE_SYNC_AFTER_SOFTWARE_UPDATE = 4096
    CONNECT_IQ_APP_DOWNLOAD = 8192
    GOLF_COURSE_DOWNLOAD = 16384
    DEVICE_INITIATES_SYNC = 32768
    CONNECT_IQ_WATCH_APP_DOWNLOAD = 65536
    CONNECT_IQ_WIDGET_DOWNLOAD = 131072
    CONNECT_IQ_WATCH_FACE_DOWNLOAD = 262144
    CONNECT_IQ_DATA_FIELD_DOWNLOAD = 524288
    CONNECT_IQ_APP_MANAGMENT = 1048576
    SWING_SENSOR = 2097152
    SWING_SENSOR_REMOTE = 4194304
    INCIDENT_DETECTION = 8388608
    AUDIO_PROMPTS = 16777216
    WIFI_VERIFICATION = 33554432
    TRUE_UP = 67108864
    FIND_MY_WATCH = 134217728
    REMOTE_MANUAL_SYNC = 268435456
    LIVE_TRACK_AUTO_START = 536870912
    LIVE_TRACK_MESSAGING = 1073741824
    INSTANT_INPUT = 2147483648


class WeatherReport(Enum):
    CURRENT = 0
    FORECAST = 1
    HOURLY_FORECAST = 1
    DAILY_FORECAST = 2


class WeatherStatus(Enum):
    CLEAR = 0
    PARTLY_CLOUDY = 1
    MOSTLY_CLOUDY = 2
    RAIN = 3
    SNOW = 4
    WINDY = 5
    THUNDERSTORMS = 6
    WINTRY_MIX = 7
    FOG = 8
    HAZY = 11
    HAIL = 12
    SCATTERED_SHOWERS = 13
    SCATTERED_THUNDERSTORMS = 14
    UNKNOWN_PRECIPITATION = 15
    LIGHT_RAIN = 16
    HEAVY_RAIN = 17
    LIGHT_SNOW = 18
    HEAVY_SNOW = 19
    LIGHT_RAIN_SNOW = 20
    HEAVY_RAIN_SNOW = 21
    CLOUDY = 22


class WeatherSeverity(Enum):
    UNKNOWN = 0
    WARNING = 1
    WATCH = 2
    ADVISORY = 3
    STATEMENT = 4


class WeatherSevereType(Enum):
    UNSPECIFIED = 0
    TORNADO = 1
    TSUNAMI = 2
    HURRICANE = 3
    EXTREME_WIND = 4
    TYPHOON = 5
    INLAND_HURRICANE = 6
    HURRICANE_FORCE_WIND = 7
    WATERSPOUT = 8
    SEVERE_THUNDERSTORM = 9
    WRECKHOUSE_WINDS = 10
    LES_SUETES_WIND = 11
    AVALANCHE = 12
    FLASH_FLOOD = 13
    TROPICAL_STORM = 14
    INLAND_TROPICAL_STORM = 15
    BLIZZARD = 16
    ICE_STORM = 17
    FREEZING_RAIN = 18
    DEBRIS_FLOW = 19
    FLASH_FREEZE = 20
    DUST_STORM = 21
    HIGH_WIND = 22
    WINTER_STORM = 23
    HEAVY_FREEZING_SPRAY = 24
    EXTREME_COLD = 25
    WIND_CHILL = 26
    COLD_WAVE = 27
    HEAVY_SNOW_ALERT = 28
    LAKE_EFFECT_BLOWING_SNOW = 29
    SNOW_SQUALL = 30
    LAKE_EFFECT_SNOW = 31
    WINTER_WEATHER = 32
    SLEET = 33
    SNOWFALL = 34
    SNOW_AND_BLOWING_SNOW = 35
    BLOWING_SNOW = 36
    SNOW_ALERT = 37
    ARCTIC_OUTFLOW = 38
    FREEZING_DRIZZLE = 39
    STORM = 40
    STORM_SURGE = 41
    RAINFALL = 42
    AREAL_FLOOD = 43
    COASTAL_FLOOD = 44
    LAKESHORE_FLOOD = 45
    EXCESSIVE_HEAT = 46
    HEAT = 47
    WEATHER = 48
    HIGH_HEAT_AND_HUMIDITY = 49
    HUMIDEX_AND_HEALTH = 50
    HUMIDEX = 51
    GALE = 52
    FREEZING_SPRAY = 53
    SPECIAL_MARINE = 54
    SQUALL = 55
    STRONG_WIND = 56
    LAKE_WIND = 57
    MARINE_WEATHER = 58
    WIND = 59
    SMALL_CRAFT_HAZARDOUS_SEAS = 60
    HAZARDOUS_SEAS = 61
    SMALL_CRAFT = 62
    SMALL_CRAFT_WINDS = 63
    SMALL_CRAFT_ROUGH_BAR = 64
    HIGH_WATER_LEVEL = 65
    ASHFALL = 66
    FREEZING_FOG = 67
    DENSE_FOG = 68
    DENSE_SMOKE = 69
    BLOWING_DUST = 70
    HARD_FREEZE = 71
    FREEZE = 72
    FROST = 73
    FIRE_WEATHER = 74
    FLOOD = 75
    RIP_TIDE = 76
    HIGH_SURF = 77
    SMOG = 78
    AIR_QUALITY = 79
    BRISK_WIND = 80
    AIR_STAGNATION = 81
    LOW_WATER = 82
    HYDROLOGICAL = 83
    SPECIAL_WEATHER = 84


class StrokeType(Enum):
    NO_EVENT = 0
    OTHER = 1
    SERVE = 2
    FOREHAND = 3
    BACKHAND = 4
    SMASH = 5


class BodyLocation(Enum):
    LEFT_LEG = 0
    LEFT_CALF = 1
    LEFT_SHIN = 2
    LEFT_HAMSTRING = 3
    LEFT_QUAD = 4
    LEFT_GLUTE = 5
    RIGHT_LEG = 6
    RIGHT_CALF = 7
    RIGHT_SHIN = 8
    RIGHT_HAMSTRING = 9
    RIGHT_QUAD = 10
    RIGHT_GLUTE = 11
    TORSO_BACK = 12
    LEFT_LOWER_BACK = 13
    LEFT_UPPER_BACK = 14
    RIGHT_LOWER_BACK = 15
    RIGHT_UPPER_BACK = 16
    TORSO_FRONT = 17
    LEFT_ABDOMEN = 18
    LEFT_CHEST = 19
    RIGHT_ABDOMEN = 20
    RIGHT_CHEST = 21
    LEFT_ARM = 22
    LEFT_SHOULDER = 23
    LEFT_BICEP = 24
    LEFT_TRICEP = 25
    LEFT_BRACHIORADIALIS = 26
    LEFT_FOREARM_EXTENSORS = 27
    RIGHT_ARM = 28
    RIGHT_SHOULDER = 29
    RIGHT_BICEP = 30
    RIGHT_TRICEP = 31
    RIGHT_BRACHIORADIALIS = 32
    RIGHT_FOREARM_EXTENSORS = 33
    NECK = 34
    THROAT = 35
    WAIST_MID_BACK = 36
    WAIST_FRONT = 37
    WAIST_LEFT = 38
    WAIST_RIGHT = 39


class SegmentLapStatus(Enum):
    END = 0
    FAIL = 1


class SegmentLeaderboardType(Enum):
    OVERALL = 0
    PERSONAL_BEST = 1
    CONNECTIONS = 2
    GROUP = 3
    CHALLENGER = 4
    KOM = 5
    QOM = 6
    PR = 7
    GOAL = 8
    RIVAL = 9
    CLUB_LEADER = 10


class SegmentDeleteStatus(Enum):
    DO_NOT_DELETE = 0
    DELETE_ONE = 1
    DELETE_ALL = 2


class SegmentSelectionType(Enum):
    STARRED = 0
    SUGGESTED = 1


class SourceType(Enum):
    ANT = 0
    ANTPLUS = 1
    BLUETOOTH = 2
    BLUETOOTH_LOW_ENERGY = 3
    WIFI = 4
    LOCAL = 5


class DisplayOrientation(Enum):
    AUTO = 0
    PORTRAIT = 1
    LANDSCAPE = 2
    PORTRAIT_FLIPPED = 3
    LANDSCAPE_FLIPPED = 4


class WorkoutEquipment(Enum):
    NONE = 0
    SWIM_FINS = 1
    SWIM_KICKBOARD = 2
    SWIM_PADDLES = 3
    SWIM_PULL_BUOY = 4
    SWIM_SNORKEL = 5


class WatchfaceMode(Enum):
    DIGITAL = 0
    ANALOG = 1
    CONNECT_IQ = 2
    DISABLED = 3


class DigitalWatchfaceLayout(Enum):
    TRADITIONAL = 0
    MODERN = 1
    BOLD = 2


class AnalogWatchfaceLayout(Enum):
    MINIMAL = 0
    TRADITIONAL = 1
    MODERN = 2


class RiderPositionType(Enum):
    SEATED = 0
    STANDING = 1
    TRANSITION_TO_SEATED = 2
    TRANSITION_TO_STANDING = 3


class PowerPhaseType(Enum):
    POWER_PHASE_START_ANGLE = 0
    POWER_PHASE_END_ANGLE = 1
    POWER_PHASE_ARC_LENGTH = 2
    POWER_PHASE_CENTER = 3


class CameraEventType(Enum):
    VIDEO_START = 0
    VIDEO_SPLIT = 1
    VIDEO_END = 2
    PHOTO_TAKEN = 3
    VIDEO_SECOND_STREAM_START = 4
    VIDEO_SECOND_STREAM_SPLIT = 5
    VIDEO_SECOND_STREAM_END = 6
    VIDEO_SPLIT_START = 7
    VIDEO_SECOND_STREAM_SPLIT_START = 8
    VIDEO_PAUSE = 11
    VIDEO_SECOND_STREAM_PAUSE = 12
    VIDEO_RESUME = 13
    VIDEO_SECOND_STREAM_RESUME = 14


class SensorType(Enum):
    ACCELEROMETER = 0
    GYROSCOPE = 1
    COMPASS = 2
    BAROMETER = 3


class BikeLightNetworkConfigType(Enum):
    AUTO = 0
    INDIVIDUAL = 4
    HIGH_VISIBILITY = 5
    TRAIL = 6


class CommTimeoutType(Enum):
    WILDCARD_PAIRING_TIMEOUT = 0
    PAIRING_TIMEOUT = 1
    CONNECTION_LOST = 2
    CONNECTION_TIMEOUT = 3


class CameraOrientationType(Enum):
    CAMERA_ORIENTATION_0 = 0
    CAMERA_ORIENTATION_90 = 1
    CAMERA_ORIENTATION_180 = 2
    CAMERA_ORIENTATION_270 = 3


class AttitudeStage(Enum):
    FAILED = 0
    ALIGNING = 1
    DEGRADED = 2
    VALID = 3


class AttitudeValidity(Enum):
    TRACK_ANGLE_HEADING_VALID = 1
    PITCH_VALID = 2
    ROLL_VALID = 4
    LATERAL_BODY_ACCEL_VALID = 8
    NORMAL_BODY_ACCEL_VALID = 16
    TURN_RATE_VALID = 32
    HW_FAIL = 64
    MAG_INVALID = 128
    NO_GPS = 256
    GPS_INVALID = 512
    SOLUTION_COASTING = 1024
    TRUE_TRACK_ANGLE = 2048
    MAGNETIC_HEADING = 4096


class AutoSyncFrequency(Enum):
    NEVER = 0
    OCCASIONALLY = 1
    FREQUENT = 2
    ONCE_A_DAY = 3
    REMOTE = 4


class ExdLayout(Enum):
    FULL_SCREEN = 0
    HALF_VERTICAL = 1
    HALF_HORIZONTAL = 2
    HALF_VERTICAL_RIGHT_SPLIT = 3
    HALF_HORIZONTAL_BOTTOM_SPLIT = 4
    FULL_QUARTER_SPLIT = 5
    HALF_VERTICAL_LEFT_SPLIT = 6
    HALF_HORIZONTAL_TOP_SPLIT = 7
    DYNAMIC = 8


class ExdDisplayType(Enum):
    NUMERICAL = 0
    SIMPLE = 1
    GRAPH = 2
    BAR = 3
    CIRCLE_GRAPH = 4
    VIRTUAL_PARTNER = 5
    BALANCE = 6
    STRING_LIST = 7
    STRING = 8
    SIMPLE_DYNAMIC_ICON = 9
    GAUGE = 10


class ExdDataUnits(Enum):
    NO_UNITS = 0
    LAPS = 1
    MILES_PER_HOUR = 2
    KILOMETERS_PER_HOUR = 3
    FEET_PER_HOUR = 4
    METERS_PER_HOUR = 5
    DEGREES_CELSIUS = 6
    DEGREES_FARENHEIT = 7
    ZONE = 8
    GEAR = 9
    RPM = 10
    BPM = 11
    DEGREES = 12
    MILLIMETERS = 13
    METERS = 14
    KILOMETERS = 15
    FEET = 16
    YARDS = 17
    KILOFEET = 18
    MILES = 19
    TIME = 20
    ENUM_TURN_TYPE = 21
    PERCENT = 22
    WATTS = 23
    WATTS_PER_KILOGRAM = 24
    ENUM_BATTERY_STATUS = 25
    ENUM_BIKE_LIGHT_BEAM_ANGLE_MODE = 26
    ENUM_BIKE_LIGHT_BATTERY_STATUS = 27
    ENUM_BIKE_LIGHT_NETWORK_CONFIG_TYPE = 28
    LIGHTS = 29
    SECONDS = 30
    MINUTES = 31
    HOURS = 32
    CALORIES = 33
    KILOJOULES = 34
    MILLISECONDS = 35
    SECOND_PER_MILE = 36
    SECOND_PER_KILOMETER = 37
    CENTIMETER = 38
    ENUM_COURSE_POINT = 39
    BRADIANS = 40
    ENUM_SPORT = 41
    INCHES_HG = 42
    MM_HG = 43
    MBARS = 44
    HECTO_PASCALS = 45
    FEET_PER_MIN = 46
    METERS_PER_MIN = 47
    METERS_PER_SEC = 48
    EIGHT_CARDINAL = 49


class ExdQualifiers(Enum):
    NO_QUALIFIER = 0
    INSTANTANEOUS = 1
    AVERAGE = 2
    LAP = 3
    MAXIMUM = 4
    MAXIMUM_AVERAGE = 5
    MAXIMUM_LAP = 6
    LAST_LAP = 7
    AVERAGE_LAP = 8
    TO_DESTINATION = 9
    TO_GO = 10
    TO_NEXT = 11
    NEXT_COURSE_POINT = 12
    TOTAL = 13
    THREE_SECOND_AVERAGE = 14
    TEN_SECOND_AVERAGE = 15
    THIRTY_SECOND_AVERAGE = 16
    PERCENT_MAXIMUM = 17
    PERCENT_MAXIMUM_AVERAGE = 18
    LAP_PERCENT_MAXIMUM = 19
    ELAPSED = 20
    SUNRISE = 21
    SUNSET = 22
    COMPARED_TO_VIRTUAL_PARTNER = 23
    MAXIMUM_24H = 24
    MINIMUM_24H = 25
    MINIMUM = 26
    FIRST = 27
    SECOND = 28
    THIRD = 29
    SHIFTER = 30
    LAST_SPORT = 31
    MOVING = 32
    STOPPED = 33
    ESTIMATED_TOTAL = 34
    ZONE_9 = 242
    ZONE_8 = 243
    ZONE_7 = 244
    ZONE_6 = 245
    ZONE_5 = 246
    ZONE_4 = 247
    ZONE_3 = 248
    ZONE_2 = 249
    ZONE_1 = 250


class ExdDescriptors(Enum):
    BIKE_LIGHT_BATTERY_STATUS = 0
    BEAM_ANGLE_STATUS = 1
    BATERY_LEVEL = 2
    LIGHT_NETWORK_MODE = 3
    NUMBER_LIGHTS_CONNECTED = 4
    CADENCE = 5
    DISTANCE = 6
    ESTIMATED_TIME_OF_ARRIVAL = 7
    HEADING = 8
    TIME = 9
    BATTERY_LEVEL = 10
    TRAINER_RESISTANCE = 11
    TRAINER_TARGET_POWER = 12
    TIME_SEATED = 13
    TIME_STANDING = 14
    ELEVATION = 15
    GRADE = 16
    ASCENT = 17
    DESCENT = 18
    VERTICAL_SPEED = 19
    DI2_BATTERY_LEVEL = 20
    FRONT_GEAR = 21
    REAR_GEAR = 22
    GEAR_RATIO = 23
    HEART_RATE = 24
    HEART_RATE_ZONE = 25
    TIME_IN_HEART_RATE_ZONE = 26
    HEART_RATE_RESERVE = 27
    CALORIES = 28
    GPS_ACCURACY = 29
    GPS_SIGNAL_STRENGTH = 30
    TEMPERATURE = 31
    TIME_OF_DAY = 32
    BALANCE = 33
    PEDAL_SMOOTHNESS = 34
    POWER = 35
    FUNCTIONAL_THRESHOLD_POWER = 36
    INTENSITY_FACTOR = 37
    WORK = 38
    POWER_RATIO = 39
    NORMALIZED_POWER = 40
    TRAINING_STRESS_SCORE = 41
    TIME_ON_ZONE = 42
    SPEED = 43
    LAPS = 44
    REPS = 45
    WORKOUT_STEP = 46
    COURSE_DISTANCE = 47
    NAVIGATION_DISTANCE = 48
    COURSE_ESTIMATED_TIME_OF_ARRIVAL = 49
    NAVIGATION_ESTIMATED_TIME_OF_ARRIVAL = 50
    COURSE_TIME = 51
    NAVIGATION_TIME = 52
    COURSE_HEADING = 53
    NAVIGATION_HEADING = 54
    POWER_ZONE = 55
    TORQUE_EFFECTIVENESS = 56
    TIMER_TIME = 57
    POWER_WEIGHT_RATIO = 58
    LEFT_PLATFORM_CENTER_OFFSET = 59
    RIGHT_PLATFORM_CENTER_OFFSET = 60
    LEFT_POWER_PHASE_START_ANGLE = 61
    RIGHT_POWER_PHASE_START_ANGLE = 62
    LEFT_POWER_PHASE_FINISH_ANGLE = 63
    RIGHT_POWER_PHASE_FINISH_ANGLE = 64
    GEARS = 65
    PACE = 66
    TRAINING_EFFECT = 67
    VERTICAL_OSCILLATION = 68
    VERTICAL_RATIO = 69
    GROUND_CONTACT_TIME = 70
    LEFT_GROUND_CONTACT_TIME_BALANCE = 71
    RIGHT_GROUND_CONTACT_TIME_BALANCE = 72
    STRIDE_LENGTH = 73
    RUNNING_CADENCE = 74
    PERFORMANCE_CONDITION = 75
    COURSE_TYPE = 76
    TIME_IN_POWER_ZONE = 77
    NAVIGATION_TURN = 78
    COURSE_LOCATION = 79
    NAVIGATION_LOCATION = 80
    COMPASS = 81
    GEAR_COMBO = 82
    MUSCLE_OXYGEN = 83
    ICON = 84
    COMPASS_HEADING = 85
    GPS_HEADING = 86
    GPS_ELEVATION = 87
    ANAEROBIC_TRAINING_EFFECT = 88
    COURSE = 89
    OFF_COURSE = 90
    GLIDE_RATIO = 91
    VERTICAL_DISTANCE = 92
    VMG = 93
    AMBIENT_PRESSURE = 94
    PRESSURE = 95
    VAM = 96


class AutoActivityDetect(Enum):
    NONE = 0
    RUNNING = 1
    CYCLING = 2
    SWIMMING = 4
    WALKING = 8
    ELLIPTICAL = 32
    SEDENTARY = 1024


class SupportedExdScreenLayouts(Enum):
    FULL_SCREEN = 1
    HALF_VERTICAL = 2
    HALF_HORIZONTAL = 4
    HALF_VERTICAL_RIGHT_SPLIT = 8
    HALF_HORIZONTAL_BOTTOM_SPLIT = 16
    FULL_QUARTER_SPLIT = 32
    HALF_VERTICAL_LEFT_SPLIT = 64
    HALF_HORIZONTAL_TOP_SPLIT = 128


class TurnType(Enum):
    ARRIVING_IDX = 0
    ARRIVING_LEFT_IDX = 1
    ARRIVING_RIGHT_IDX = 2
    ARRIVING_VIA_IDX = 3
    ARRIVING_VIA_LEFT_IDX = 4
    ARRIVING_VIA_RIGHT_IDX = 5
    BEAR_KEEP_LEFT_IDX = 6
    BEAR_KEEP_RIGHT_IDX = 7
    CONTINUE_IDX = 8
    EXIT_LEFT_IDX = 9
    EXIT_RIGHT_IDX = 10
    FERRY_IDX = 11
    ROUNDABOUT_45_IDX = 12
    ROUNDABOUT_90_IDX = 13
    ROUNDABOUT_135_IDX = 14
    ROUNDABOUT_180_IDX = 15
    ROUNDABOUT_225_IDX = 16
    ROUNDABOUT_270_IDX = 17
    ROUNDABOUT_315_IDX = 18
    ROUNDABOUT_360_IDX = 19
    ROUNDABOUT_NEG_45_IDX = 20
    ROUNDABOUT_NEG_90_IDX = 21
    ROUNDABOUT_NEG_135_IDX = 22
    ROUNDABOUT_NEG_180_IDX = 23
    ROUNDABOUT_NEG_225_IDX = 24
    ROUNDABOUT_NEG_270_IDX = 25
    ROUNDABOUT_NEG_315_IDX = 26
    ROUNDABOUT_NEG_360_IDX = 27
    ROUNDABOUT_GENERIC_IDX = 28
    ROUNDABOUT_NEG_GENERIC_IDX = 29
    SHARP_TURN_LEFT_IDX = 30
    SHARP_TURN_RIGHT_IDX = 31
    TURN_LEFT_IDX = 32
    TURN_RIGHT_IDX = 33
    UTURN_LEFT_IDX = 34
    UTURN_RIGHT_IDX = 35
    ICON_INV_IDX = 36
    ICON_IDX_CNT = 37


class BikeLightBeamAngleMode(Enum):
    MANUAL = 0
    AUTO = 1


class FitBaseUnit(Enum):
    OTHER = 0
    KILOGRAM = 1
    POUND = 2


class SetType(Enum):
    REST = 0
    ACTIVE = 1


class ExerciseCategory(Enum):
    BENCH_PRESS = 0
    CALF_RAISE = 1
    CARDIO = 2
    CARRY = 3
    CHOP = 4
    CORE = 5
    CRUNCH = 6
    CURL = 7
    DEADLIFT = 8
    FLYE = 9
    HIP_RAISE = 10
    HIP_STABILITY = 11
    HIP_SWING = 12
    HYPEREXTENSION = 13
    LATERAL_RAISE = 14
    LEG_CURL = 15
    LEG_RAISE = 16
    LUNGE = 17
    OLYMPIC_LIFT = 18
    PLANK = 19
    PLYO = 20
    PULL_UP = 21
    PUSH_UP = 22
    ROW = 23
    SHOULDER_PRESS = 24
    SHOULDER_STABILITY = 25
    SHRUG = 26
    SIT_UP = 27
    SQUAT = 28
    TOTAL_BODY = 29
    TRICEPS_EXTENSION = 30
    WARM_UP = 31
    RUN = 32
    UNKNOWN = 65534


class BenchPressExerciseName(Enum):
    ALTERNATING_DUMBBELL_CHEST_PRESS_ON_SWISS_BALL = 0
    BARBELL_BENCH_PRESS = 1
    BARBELL_BOARD_BENCH_PRESS = 2
    BARBELL_FLOOR_PRESS = 3
    CLOSE_GRIP_BARBELL_BENCH_PRESS = 4
    DECLINE_DUMBBELL_BENCH_PRESS = 5
    DUMBBELL_BENCH_PRESS = 6
    DUMBBELL_FLOOR_PRESS = 7
    INCLINE_BARBELL_BENCH_PRESS = 8
    INCLINE_DUMBBELL_BENCH_PRESS = 9
    INCLINE_SMITH_MACHINE_BENCH_PRESS = 10
    ISOMETRIC_BARBELL_BENCH_PRESS = 11
    KETTLEBELL_CHEST_PRESS = 12
    NEUTRAL_GRIP_DUMBBELL_BENCH_PRESS = 13
    NEUTRAL_GRIP_DUMBBELL_INCLINE_BENCH_PRESS = 14
    ONE_ARM_FLOOR_PRESS = 15
    WEIGHTED_ONE_ARM_FLOOR_PRESS = 16
    PARTIAL_LOCKOUT = 17
    REVERSE_GRIP_BARBELL_BENCH_PRESS = 18
    REVERSE_GRIP_INCLINE_BENCH_PRESS = 19
    SINGLE_ARM_CABLE_CHEST_PRESS = 20
    SINGLE_ARM_DUMBBELL_BENCH_PRESS = 21
    SMITH_MACHINE_BENCH_PRESS = 22
    SWISS_BALL_DUMBBELL_CHEST_PRESS = 23
    TRIPLE_STOP_BARBELL_BENCH_PRESS = 24
    WIDE_GRIP_BARBELL_BENCH_PRESS = 25
    ALTERNATING_DUMBBELL_CHEST_PRESS = 26


class CalfRaiseExerciseName(Enum):
    N3_WAY_CALF_RAISE = 0
    N3_WAY_WEIGHTED_CALF_RAISE = 1
    N3_WAY_SINGLE_LEG_CALF_RAISE = 2
    N3_WAY_WEIGHTED_SINGLE_LEG_CALF_RAISE = 3
    DONKEY_CALF_RAISE = 4
    WEIGHTED_DONKEY_CALF_RAISE = 5
    SEATED_CALF_RAISE = 6
    WEIGHTED_SEATED_CALF_RAISE = 7
    SEATED_DUMBBELL_TOE_RAISE = 8
    SINGLE_LEG_BENT_KNEE_CALF_RAISE = 9
    WEIGHTED_SINGLE_LEG_BENT_KNEE_CALF_RAISE = 10
    SINGLE_LEG_DECLINE_PUSH_UP = 11
    SINGLE_LEG_DONKEY_CALF_RAISE = 12
    WEIGHTED_SINGLE_LEG_DONKEY_CALF_RAISE = 13
    SINGLE_LEG_HIP_RAISE_WITH_KNEE_HOLD = 14
    SINGLE_LEG_STANDING_CALF_RAISE = 15
    SINGLE_LEG_STANDING_DUMBBELL_CALF_RAISE = 16
    STANDING_BARBELL_CALF_RAISE = 17
    STANDING_CALF_RAISE = 18
    WEIGHTED_STANDING_CALF_RAISE = 19
    STANDING_DUMBBELL_CALF_RAISE = 20


class CardioExerciseName(Enum):
    BOB_AND_WEAVE_CIRCLE = 0
    WEIGHTED_BOB_AND_WEAVE_CIRCLE = 1
    CARDIO_CORE_CRAWL = 2
    WEIGHTED_CARDIO_CORE_CRAWL = 3
    DOUBLE_UNDER = 4
    WEIGHTED_DOUBLE_UNDER = 5
    JUMP_ROPE = 6
    WEIGHTED_JUMP_ROPE = 7
    JUMP_ROPE_CROSSOVER = 8
    WEIGHTED_JUMP_ROPE_CROSSOVER = 9
    JUMP_ROPE_JOG = 10
    WEIGHTED_JUMP_ROPE_JOG = 11
    JUMPING_JACKS = 12
    WEIGHTED_JUMPING_JACKS = 13
    SKI_MOGULS = 14
    WEIGHTED_SKI_MOGULS = 15
    SPLIT_JACKS = 16
    WEIGHTED_SPLIT_JACKS = 17
    SQUAT_JACKS = 18
    WEIGHTED_SQUAT_JACKS = 19
    TRIPLE_UNDER = 20
    WEIGHTED_TRIPLE_UNDER = 21


class CarryExerciseName(Enum):
    BAR_HOLDS = 0
    FARMERS_WALK = 1
    FARMERS_WALK_ON_TOES = 2
    HEX_DUMBBELL_HOLD = 3
    OVERHEAD_CARRY = 4


class ChopExerciseName(Enum):
    CABLE_PULL_THROUGH = 0
    CABLE_ROTATIONAL_LIFT = 1
    CABLE_WOODCHOP = 2
    CROSS_CHOP_TO_KNEE = 3
    WEIGHTED_CROSS_CHOP_TO_KNEE = 4
    DUMBBELL_CHOP = 5
    HALF_KNEELING_ROTATION = 6
    WEIGHTED_HALF_KNEELING_ROTATION = 7
    HALF_KNEELING_ROTATIONAL_CHOP = 8
    HALF_KNEELING_ROTATIONAL_REVERSE_CHOP = 9
    HALF_KNEELING_STABILITY_CHOP = 10
    HALF_KNEELING_STABILITY_REVERSE_CHOP = 11
    KNEELING_ROTATIONAL_CHOP = 12
    KNEELING_ROTATIONAL_REVERSE_CHOP = 13
    KNEELING_STABILITY_CHOP = 14
    KNEELING_WOODCHOPPER = 15
    MEDICINE_BALL_WOOD_CHOPS = 16
    POWER_SQUAT_CHOPS = 17
    WEIGHTED_POWER_SQUAT_CHOPS = 18
    STANDING_ROTATIONAL_CHOP = 19
    STANDING_SPLIT_ROTATIONAL_CHOP = 20
    STANDING_SPLIT_ROTATIONAL_REVERSE_CHOP = 21
    STANDING_STABILITY_REVERSE_CHOP = 22


class CoreExerciseName(Enum):
    ABS_JABS = 0
    WEIGHTED_ABS_JABS = 1
    ALTERNATING_PLATE_REACH = 2
    BARBELL_ROLLOUT = 3
    WEIGHTED_BARBELL_ROLLOUT = 4
    BODY_BAR_OBLIQUE_TWIST = 5
    CABLE_CORE_PRESS = 6
    CABLE_SIDE_BEND = 7
    SIDE_BEND = 8
    WEIGHTED_SIDE_BEND = 9
    CRESCENT_CIRCLE = 10
    WEIGHTED_CRESCENT_CIRCLE = 11
    CYCLING_RUSSIAN_TWIST = 12
    WEIGHTED_CYCLING_RUSSIAN_TWIST = 13
    ELEVATED_FEET_RUSSIAN_TWIST = 14
    WEIGHTED_ELEVATED_FEET_RUSSIAN_TWIST = 15
    HALF_TURKISH_GET_UP = 16
    KETTLEBELL_WINDMILL = 17
    KNEELING_AB_WHEEL = 18
    WEIGHTED_KNEELING_AB_WHEEL = 19
    MODIFIED_FRONT_LEVER = 20
    OPEN_KNEE_TUCKS = 21
    WEIGHTED_OPEN_KNEE_TUCKS = 22
    SIDE_ABS_LEG_LIFT = 23
    WEIGHTED_SIDE_ABS_LEG_LIFT = 24
    SWISS_BALL_JACKKNIFE = 25
    WEIGHTED_SWISS_BALL_JACKKNIFE = 26
    SWISS_BALL_PIKE = 27
    WEIGHTED_SWISS_BALL_PIKE = 28
    SWISS_BALL_ROLLOUT = 29
    WEIGHTED_SWISS_BALL_ROLLOUT = 30
    TRIANGLE_HIP_PRESS = 31
    WEIGHTED_TRIANGLE_HIP_PRESS = 32
    TRX_SUSPENDED_JACKKNIFE = 33
    WEIGHTED_TRX_SUSPENDED_JACKKNIFE = 34
    U_BOAT = 35
    WEIGHTED_U_BOAT = 36
    WINDMILL_SWITCHES = 37
    WEIGHTED_WINDMILL_SWITCHES = 38
    ALTERNATING_SLIDE_OUT = 39
    WEIGHTED_ALTERNATING_SLIDE_OUT = 40
    GHD_BACK_EXTENSIONS = 41
    WEIGHTED_GHD_BACK_EXTENSIONS = 42
    OVERHEAD_WALK = 43
    INCHWORM = 44
    WEIGHTED_MODIFIED_FRONT_LEVER = 45
    RUSSIAN_TWIST = 46
    ABDOMINAL_LEG_ROTATIONS = 47
    ARM_AND_LEG_EXTENSION_ON_KNEES = 48
    BICYCLE = 49
    BICEP_CURL_WITH_LEG_EXTENSION = 50
    CAT_COW = 51
    CORKSCREW = 52
    CRISS_CROSS = 53
    CRISS_CROSS_WITH_BALL = 54
    DOUBLE_LEG_STRETCH = 55
    KNEE_FOLDS = 56
    LOWER_LIFT = 57
    NECK_PULL = 58
    PELVIC_CLOCKS = 59
    ROLL_OVER = 60
    ROLL_UP = 61
    ROLLING = 62
    ROWING_1 = 63
    ROWING_2 = 64
    SCISSORS = 65
    SINGLE_LEG_CIRCLES = 66
    SINGLE_LEG_STRETCH = 67
    SNAKE_TWIST_1_AND_2 = 68
    SWAN = 69
    SWIMMING = 70
    TEASER = 71
    THE_HUNDRED = 72


class CrunchExerciseName(Enum):
    BICYCLE_CRUNCH = 0
    CABLE_CRUNCH = 1
    CIRCULAR_ARM_CRUNCH = 2
    CROSSED_ARMS_CRUNCH = 3
    WEIGHTED_CROSSED_ARMS_CRUNCH = 4
    CROSS_LEG_REVERSE_CRUNCH = 5
    WEIGHTED_CROSS_LEG_REVERSE_CRUNCH = 6
    CRUNCH_CHOP = 7
    WEIGHTED_CRUNCH_CHOP = 8
    DOUBLE_CRUNCH = 9
    WEIGHTED_DOUBLE_CRUNCH = 10
    ELBOW_TO_KNEE_CRUNCH = 11
    WEIGHTED_ELBOW_TO_KNEE_CRUNCH = 12
    FLUTTER_KICKS = 13
    WEIGHTED_FLUTTER_KICKS = 14
    FOAM_ROLLER_REVERSE_CRUNCH_ON_BENCH = 15
    WEIGHTED_FOAM_ROLLER_REVERSE_CRUNCH_ON_BENCH = 16
    FOAM_ROLLER_REVERSE_CRUNCH_WITH_DUMBBELL = 17
    FOAM_ROLLER_REVERSE_CRUNCH_WITH_MEDICINE_BALL = 18
    FROG_PRESS = 19
    HANGING_KNEE_RAISE_OBLIQUE_CRUNCH = 20
    WEIGHTED_HANGING_KNEE_RAISE_OBLIQUE_CRUNCH = 21
    HIP_CROSSOVER = 22
    WEIGHTED_HIP_CROSSOVER = 23
    HOLLOW_ROCK = 24
    WEIGHTED_HOLLOW_ROCK = 25
    INCLINE_REVERSE_CRUNCH = 26
    WEIGHTED_INCLINE_REVERSE_CRUNCH = 27
    KNEELING_CABLE_CRUNCH = 28
    KNEELING_CROSS_CRUNCH = 29
    WEIGHTED_KNEELING_CROSS_CRUNCH = 30
    KNEELING_OBLIQUE_CABLE_CRUNCH = 31
    KNEES_TO_ELBOW = 32
    LEG_EXTENSIONS = 33
    WEIGHTED_LEG_EXTENSIONS = 34
    LEG_LEVERS = 35
    MCGILL_CURL_UP = 36
    WEIGHTED_MCGILL_CURL_UP = 37
    MODIFIED_PILATES_ROLL_UP_WITH_BALL = 38
    WEIGHTED_MODIFIED_PILATES_ROLL_UP_WITH_BALL = 39
    PILATES_CRUNCH = 40
    WEIGHTED_PILATES_CRUNCH = 41
    PILATES_ROLL_UP_WITH_BALL = 42
    WEIGHTED_PILATES_ROLL_UP_WITH_BALL = 43
    RAISED_LEGS_CRUNCH = 44
    WEIGHTED_RAISED_LEGS_CRUNCH = 45
    REVERSE_CRUNCH = 46
    WEIGHTED_REVERSE_CRUNCH = 47
    REVERSE_CRUNCH_ON_A_BENCH = 48
    WEIGHTED_REVERSE_CRUNCH_ON_A_BENCH = 49
    REVERSE_CURL_AND_LIFT = 50
    WEIGHTED_REVERSE_CURL_AND_LIFT = 51
    ROTATIONAL_LIFT = 52
    WEIGHTED_ROTATIONAL_LIFT = 53
    SEATED_ALTERNATING_REVERSE_CRUNCH = 54
    WEIGHTED_SEATED_ALTERNATING_REVERSE_CRUNCH = 55
    SEATED_LEG_U = 56
    WEIGHTED_SEATED_LEG_U = 57
    SIDE_TO_SIDE_CRUNCH_AND_WEAVE = 58
    WEIGHTED_SIDE_TO_SIDE_CRUNCH_AND_WEAVE = 59
    SINGLE_LEG_REVERSE_CRUNCH = 60
    WEIGHTED_SINGLE_LEG_REVERSE_CRUNCH = 61
    SKATER_CRUNCH_CROSS = 62
    WEIGHTED_SKATER_CRUNCH_CROSS = 63
    STANDING_CABLE_CRUNCH = 64
    STANDING_SIDE_CRUNCH = 65
    STEP_CLIMB = 66
    WEIGHTED_STEP_CLIMB = 67
    SWISS_BALL_CRUNCH = 68
    SWISS_BALL_REVERSE_CRUNCH = 69
    WEIGHTED_SWISS_BALL_REVERSE_CRUNCH = 70
    SWISS_BALL_RUSSIAN_TWIST = 71
    WEIGHTED_SWISS_BALL_RUSSIAN_TWIST = 72
    SWISS_BALL_SIDE_CRUNCH = 73
    WEIGHTED_SWISS_BALL_SIDE_CRUNCH = 74
    THORACIC_CRUNCHES_ON_FOAM_ROLLER = 75
    WEIGHTED_THORACIC_CRUNCHES_ON_FOAM_ROLLER = 76
    TRICEPS_CRUNCH = 77
    WEIGHTED_BICYCLE_CRUNCH = 78
    WEIGHTED_CRUNCH = 79
    WEIGHTED_SWISS_BALL_CRUNCH = 80
    TOES_TO_BAR = 81
    WEIGHTED_TOES_TO_BAR = 82
    CRUNCH = 83
    STRAIGHT_LEG_CRUNCH_WITH_BALL = 84


class CurlExerciseName(Enum):
    ALTERNATING_DUMBBELL_BICEPS_CURL = 0
    ALTERNATING_DUMBBELL_BICEPS_CURL_ON_SWISS_BALL = 1
    ALTERNATING_INCLINE_DUMBBELL_BICEPS_CURL = 2
    BARBELL_BICEPS_CURL = 3
    BARBELL_REVERSE_WRIST_CURL = 4
    BARBELL_WRIST_CURL = 5
    BEHIND_THE_BACK_BARBELL_REVERSE_WRIST_CURL = 6
    BEHIND_THE_BACK_ONE_ARM_CABLE_CURL = 7
    CABLE_BICEPS_CURL = 8
    CABLE_HAMMER_CURL = 9
    CHEATING_BARBELL_BICEPS_CURL = 10
    CLOSE_GRIP_EZ_BAR_BICEPS_CURL = 11
    CROSS_BODY_DUMBBELL_HAMMER_CURL = 12
    DEAD_HANG_BICEPS_CURL = 13
    DECLINE_HAMMER_CURL = 14
    DUMBBELL_BICEPS_CURL_WITH_STATIC_HOLD = 15
    DUMBBELL_HAMMER_CURL = 16
    DUMBBELL_REVERSE_WRIST_CURL = 17
    DUMBBELL_WRIST_CURL = 18
    EZ_BAR_PREACHER_CURL = 19
    FORWARD_BEND_BICEPS_CURL = 20
    HAMMER_CURL_TO_PRESS = 21
    INCLINE_DUMBBELL_BICEPS_CURL = 22
    INCLINE_OFFSET_THUMB_DUMBBELL_CURL = 23
    KETTLEBELL_BICEPS_CURL = 24
    LYING_CONCENTRATION_CABLE_CURL = 25
    ONE_ARM_PREACHER_CURL = 26
    PLATE_PINCH_CURL = 27
    PREACHER_CURL_WITH_CABLE = 28
    REVERSE_EZ_BAR_CURL = 29
    REVERSE_GRIP_WRIST_CURL = 30
    REVERSE_GRIP_BARBELL_BICEPS_CURL = 31
    SEATED_ALTERNATING_DUMBBELL_BICEPS_CURL = 32
    SEATED_DUMBBELL_BICEPS_CURL = 33
    SEATED_REVERSE_DUMBBELL_CURL = 34
    SPLIT_STANCE_OFFSET_PINKY_DUMBBELL_CURL = 35
    STANDING_ALTERNATING_DUMBBELL_CURLS = 36
    STANDING_DUMBBELL_BICEPS_CURL = 37
    STANDING_EZ_BAR_BICEPS_CURL = 38
    STATIC_CURL = 39
    SWISS_BALL_DUMBBELL_OVERHEAD_TRICEPS_EXTENSION = 40
    SWISS_BALL_EZ_BAR_PREACHER_CURL = 41
    TWISTING_STANDING_DUMBBELL_BICEPS_CURL = 42
    WIDE_GRIP_EZ_BAR_BICEPS_CURL = 43


class DeadliftExerciseName(Enum):
    BARBELL_DEADLIFT = 0
    BARBELL_STRAIGHT_LEG_DEADLIFT = 1
    DUMBBELL_DEADLIFT = 2
    DUMBBELL_SINGLE_LEG_DEADLIFT_TO_ROW = 3
    DUMBBELL_STRAIGHT_LEG_DEADLIFT = 4
    KETTLEBELL_FLOOR_TO_SHELF = 5
    ONE_ARM_ONE_LEG_DEADLIFT = 6
    RACK_PULL = 7
    ROTATIONAL_DUMBBELL_STRAIGHT_LEG_DEADLIFT = 8
    SINGLE_ARM_DEADLIFT = 9
    SINGLE_LEG_BARBELL_DEADLIFT = 10
    SINGLE_LEG_BARBELL_STRAIGHT_LEG_DEADLIFT = 11
    SINGLE_LEG_DEADLIFT_WITH_BARBELL = 12
    SINGLE_LEG_RDL_CIRCUIT = 13
    SINGLE_LEG_ROMANIAN_DEADLIFT_WITH_DUMBBELL = 14
    SUMO_DEADLIFT = 15
    SUMO_DEADLIFT_HIGH_PULL = 16
    TRAP_BAR_DEADLIFT = 17
    WIDE_GRIP_BARBELL_DEADLIFT = 18


class FlyeExerciseName(Enum):
    CABLE_CROSSOVER = 0
    DECLINE_DUMBBELL_FLYE = 1
    DUMBBELL_FLYE = 2
    INCLINE_DUMBBELL_FLYE = 3
    KETTLEBELL_FLYE = 4
    KNEELING_REAR_FLYE = 5
    SINGLE_ARM_STANDING_CABLE_REVERSE_FLYE = 6
    SWISS_BALL_DUMBBELL_FLYE = 7
    ARM_ROTATIONS = 8
    HUG_A_TREE = 9


class HipRaiseExerciseName(Enum):
    BARBELL_HIP_THRUST_ON_FLOOR = 0
    BARBELL_HIP_THRUST_WITH_BENCH = 1
    BENT_KNEE_SWISS_BALL_REVERSE_HIP_RAISE = 2
    WEIGHTED_BENT_KNEE_SWISS_BALL_REVERSE_HIP_RAISE = 3
    BRIDGE_WITH_LEG_EXTENSION = 4
    WEIGHTED_BRIDGE_WITH_LEG_EXTENSION = 5
    CLAM_BRIDGE = 6
    FRONT_KICK_TABLETOP = 7
    WEIGHTED_FRONT_KICK_TABLETOP = 8
    HIP_EXTENSION_AND_CROSS = 9
    WEIGHTED_HIP_EXTENSION_AND_CROSS = 10
    HIP_RAISE = 11
    WEIGHTED_HIP_RAISE = 12
    HIP_RAISE_WITH_FEET_ON_SWISS_BALL = 13
    WEIGHTED_HIP_RAISE_WITH_FEET_ON_SWISS_BALL = 14
    HIP_RAISE_WITH_HEAD_ON_BOSU_BALL = 15
    WEIGHTED_HIP_RAISE_WITH_HEAD_ON_BOSU_BALL = 16
    HIP_RAISE_WITH_HEAD_ON_SWISS_BALL = 17
    WEIGHTED_HIP_RAISE_WITH_HEAD_ON_SWISS_BALL = 18
    HIP_RAISE_WITH_KNEE_SQUEEZE = 19
    WEIGHTED_HIP_RAISE_WITH_KNEE_SQUEEZE = 20
    INCLINE_REAR_LEG_EXTENSION = 21
    WEIGHTED_INCLINE_REAR_LEG_EXTENSION = 22
    KETTLEBELL_SWING = 23
    MARCHING_HIP_RAISE = 24
    WEIGHTED_MARCHING_HIP_RAISE = 25
    MARCHING_HIP_RAISE_WITH_FEET_ON_A_SWISS_BALL = 26
    WEIGHTED_MARCHING_HIP_RAISE_WITH_FEET_ON_A_SWISS_BALL = 27
    REVERSE_HIP_RAISE = 28
    WEIGHTED_REVERSE_HIP_RAISE = 29
    SINGLE_LEG_HIP_RAISE = 30
    WEIGHTED_SINGLE_LEG_HIP_RAISE = 31
    SINGLE_LEG_HIP_RAISE_WITH_FOOT_ON_BENCH = 32
    WEIGHTED_SINGLE_LEG_HIP_RAISE_WITH_FOOT_ON_BENCH = 33
    SINGLE_LEG_HIP_RAISE_WITH_FOOT_ON_BOSU_BALL = 34
    WEIGHTED_SINGLE_LEG_HIP_RAISE_WITH_FOOT_ON_BOSU_BALL = 35
    SINGLE_LEG_HIP_RAISE_WITH_FOOT_ON_FOAM_ROLLER = 36
    WEIGHTED_SINGLE_LEG_HIP_RAISE_WITH_FOOT_ON_FOAM_ROLLER = 37
    SINGLE_LEG_HIP_RAISE_WITH_FOOT_ON_MEDICINE_BALL = 38
    WEIGHTED_SINGLE_LEG_HIP_RAISE_WITH_FOOT_ON_MEDICINE_BALL = 39
    SINGLE_LEG_HIP_RAISE_WITH_HEAD_ON_BOSU_BALL = 40
    WEIGHTED_SINGLE_LEG_HIP_RAISE_WITH_HEAD_ON_BOSU_BALL = 41
    WEIGHTED_CLAM_BRIDGE = 42
    SINGLE_LEG_SWISS_BALL_HIP_RAISE_AND_LEG_CURL = 43
    CLAMS = 44
    INNER_THIGH_CIRCLES = 45
    INNER_THIGH_SIDE_LIFT = 46
    LEG_CIRCLES = 47
    LEG_LIFT = 48
    LEG_LIFT_IN_EXTERNAL_ROTATION = 49


class HipStabilityExerciseName(Enum):
    BAND_SIDE_LYING_LEG_RAISE = 0
    DEAD_BUG = 1
    WEIGHTED_DEAD_BUG = 2
    EXTERNAL_HIP_RAISE = 3
    WEIGHTED_EXTERNAL_HIP_RAISE = 4
    FIRE_HYDRANT_KICKS = 5
    WEIGHTED_FIRE_HYDRANT_KICKS = 6
    HIP_CIRCLES = 7
    WEIGHTED_HIP_CIRCLES = 8
    INNER_THIGH_LIFT = 9
    WEIGHTED_INNER_THIGH_LIFT = 10
    LATERAL_WALKS_WITH_BAND_AT_ANKLES = 11
    PRETZEL_SIDE_KICK = 12
    WEIGHTED_PRETZEL_SIDE_KICK = 13
    PRONE_HIP_INTERNAL_ROTATION = 14
    WEIGHTED_PRONE_HIP_INTERNAL_ROTATION = 15
    QUADRUPED = 16
    QUADRUPED_HIP_EXTENSION = 17
    WEIGHTED_QUADRUPED_HIP_EXTENSION = 18
    QUADRUPED_WITH_LEG_LIFT = 19
    WEIGHTED_QUADRUPED_WITH_LEG_LIFT = 20
    SIDE_LYING_LEG_RAISE = 21
    WEIGHTED_SIDE_LYING_LEG_RAISE = 22
    SLIDING_HIP_ADDUCTION = 23
    WEIGHTED_SLIDING_HIP_ADDUCTION = 24
    STANDING_ADDUCTION = 25
    WEIGHTED_STANDING_ADDUCTION = 26
    STANDING_CABLE_HIP_ABDUCTION = 27
    STANDING_HIP_ABDUCTION = 28
    WEIGHTED_STANDING_HIP_ABDUCTION = 29
    STANDING_REAR_LEG_RAISE = 30
    WEIGHTED_STANDING_REAR_LEG_RAISE = 31
    SUPINE_HIP_INTERNAL_ROTATION = 32
    WEIGHTED_SUPINE_HIP_INTERNAL_ROTATION = 33


class HipSwingExerciseName(Enum):
    SINGLE_ARM_KETTLEBELL_SWING = 0
    SINGLE_ARM_DUMBBELL_SWING = 1
    STEP_OUT_SWING = 2


class HyperextensionExerciseName(Enum):
    BACK_EXTENSION_WITH_OPPOSITE_ARM_AND_LEG_REACH = 0
    WEIGHTED_BACK_EXTENSION_WITH_OPPOSITE_ARM_AND_LEG_REACH = 1
    BASE_ROTATIONS = 2
    WEIGHTED_BASE_ROTATIONS = 3
    BENT_KNEE_REVERSE_HYPEREXTENSION = 4
    WEIGHTED_BENT_KNEE_REVERSE_HYPEREXTENSION = 5
    HOLLOW_HOLD_AND_ROLL = 6
    WEIGHTED_HOLLOW_HOLD_AND_ROLL = 7
    KICKS = 8
    WEIGHTED_KICKS = 9
    KNEE_RAISES = 10
    WEIGHTED_KNEE_RAISES = 11
    KNEELING_SUPERMAN = 12
    WEIGHTED_KNEELING_SUPERMAN = 13
    LAT_PULL_DOWN_WITH_ROW = 14
    MEDICINE_BALL_DEADLIFT_TO_REACH = 15
    ONE_ARM_ONE_LEG_ROW = 16
    ONE_ARM_ROW_WITH_BAND = 17
    OVERHEAD_LUNGE_WITH_MEDICINE_BALL = 18
    PLANK_KNEE_TUCKS = 19
    WEIGHTED_PLANK_KNEE_TUCKS = 20
    SIDE_STEP = 21
    WEIGHTED_SIDE_STEP = 22
    SINGLE_LEG_BACK_EXTENSION = 23
    WEIGHTED_SINGLE_LEG_BACK_EXTENSION = 24
    SPINE_EXTENSION = 25
    WEIGHTED_SPINE_EXTENSION = 26
    STATIC_BACK_EXTENSION = 27
    WEIGHTED_STATIC_BACK_EXTENSION = 28
    SUPERMAN_FROM_FLOOR = 29
    WEIGHTED_SUPERMAN_FROM_FLOOR = 30
    SWISS_BALL_BACK_EXTENSION = 31
    WEIGHTED_SWISS_BALL_BACK_EXTENSION = 32
    SWISS_BALL_HYPEREXTENSION = 33
    WEIGHTED_SWISS_BALL_HYPEREXTENSION = 34
    SWISS_BALL_OPPOSITE_ARM_AND_LEG_LIFT = 35
    WEIGHTED_SWISS_BALL_OPPOSITE_ARM_AND_LEG_LIFT = 36
    SUPERMAN_ON_SWISS_BALL = 37
    COBRA = 38
    SUPINE_FLOOR_BARRE = 39


class LateralRaiseExerciseName(Enum):
    N45_DEGREE_CABLE_EXTERNAL_ROTATION = 0
    ALTERNATING_LATERAL_RAISE_WITH_STATIC_HOLD = 1
    BAR_MUSCLE_UP = 2
    BENT_OVER_LATERAL_RAISE = 3
    CABLE_DIAGONAL_RAISE = 4
    CABLE_FRONT_RAISE = 5
    CALORIE_ROW = 6
    COMBO_SHOULDER_RAISE = 7
    DUMBBELL_DIAGONAL_RAISE = 8
    DUMBBELL_V_RAISE = 9
    FRONT_RAISE = 10
    LEANING_DUMBBELL_LATERAL_RAISE = 11
    LYING_DUMBBELL_RAISE = 12
    MUSCLE_UP = 13
    ONE_ARM_CABLE_LATERAL_RAISE = 14
    OVERHAND_GRIP_REAR_LATERAL_RAISE = 15
    PLATE_RAISES = 16
    RING_DIP = 17
    WEIGHTED_RING_DIP = 18
    RING_MUSCLE_UP = 19
    WEIGHTED_RING_MUSCLE_UP = 20
    ROPE_CLIMB = 21
    WEIGHTED_ROPE_CLIMB = 22
    SCAPTION = 23
    SEATED_LATERAL_RAISE = 24
    SEATED_REAR_LATERAL_RAISE = 25
    SIDE_LYING_LATERAL_RAISE = 26
    STANDING_LIFT = 27
    SUSPENDED_ROW = 28
    UNDERHAND_GRIP_REAR_LATERAL_RAISE = 29
    WALL_SLIDE = 30
    WEIGHTED_WALL_SLIDE = 31
    ARM_CIRCLES = 32
    SHAVING_THE_HEAD = 33


class LegCurlExerciseName(Enum):
    LEG_CURL = 0
    WEIGHTED_LEG_CURL = 1
    GOOD_MORNING = 2
    SEATED_BARBELL_GOOD_MORNING = 3
    SINGLE_LEG_BARBELL_GOOD_MORNING = 4
    SINGLE_LEG_SLIDING_LEG_CURL = 5
    SLIDING_LEG_CURL = 6
    SPLIT_BARBELL_GOOD_MORNING = 7
    SPLIT_STANCE_EXTENSION = 8
    STAGGERED_STANCE_GOOD_MORNING = 9
    SWISS_BALL_HIP_RAISE_AND_LEG_CURL = 10
    ZERCHER_GOOD_MORNING = 11


class LegRaiseExerciseName(Enum):
    HANGING_KNEE_RAISE = 0
    HANGING_LEG_RAISE = 1
    WEIGHTED_HANGING_LEG_RAISE = 2
    HANGING_SINGLE_LEG_RAISE = 3
    WEIGHTED_HANGING_SINGLE_LEG_RAISE = 4
    KETTLEBELL_LEG_RAISES = 5
    LEG_LOWERING_DRILL = 6
    WEIGHTED_LEG_LOWERING_DRILL = 7
    LYING_STRAIGHT_LEG_RAISE = 8
    WEIGHTED_LYING_STRAIGHT_LEG_RAISE = 9
    MEDICINE_BALL_LEG_DROPS = 10
    QUADRUPED_LEG_RAISE = 11
    WEIGHTED_QUADRUPED_LEG_RAISE = 12
    REVERSE_LEG_RAISE = 13
    WEIGHTED_REVERSE_LEG_RAISE = 14
    REVERSE_LEG_RAISE_ON_SWISS_BALL = 15
    WEIGHTED_REVERSE_LEG_RAISE_ON_SWISS_BALL = 16
    SINGLE_LEG_LOWERING_DRILL = 17
    WEIGHTED_SINGLE_LEG_LOWERING_DRILL = 18
    WEIGHTED_HANGING_KNEE_RAISE = 19
    LATERAL_STEPOVER = 20
    WEIGHTED_LATERAL_STEPOVER = 21


class LungeExerciseName(Enum):
    OVERHEAD_LUNGE = 0
    LUNGE_MATRIX = 1
    WEIGHTED_LUNGE_MATRIX = 2
    ALTERNATING_BARBELL_FORWARD_LUNGE = 3
    ALTERNATING_DUMBBELL_LUNGE_WITH_REACH = 4
    BACK_FOOT_ELEVATED_DUMBBELL_SPLIT_SQUAT = 5
    BARBELL_BOX_LUNGE = 6
    BARBELL_BULGARIAN_SPLIT_SQUAT = 7
    BARBELL_CROSSOVER_LUNGE = 8
    BARBELL_FRONT_SPLIT_SQUAT = 9
    BARBELL_LUNGE = 10
    BARBELL_REVERSE_LUNGE = 11
    BARBELL_SIDE_LUNGE = 12
    BARBELL_SPLIT_SQUAT = 13
    CORE_CONTROL_REAR_LUNGE = 14
    DIAGONAL_LUNGE = 15
    DROP_LUNGE = 16
    DUMBBELL_BOX_LUNGE = 17
    DUMBBELL_BULGARIAN_SPLIT_SQUAT = 18
    DUMBBELL_CROSSOVER_LUNGE = 19
    DUMBBELL_DIAGONAL_LUNGE = 20
    DUMBBELL_LUNGE = 21
    DUMBBELL_LUNGE_AND_ROTATION = 22
    DUMBBELL_OVERHEAD_BULGARIAN_SPLIT_SQUAT = 23
    DUMBBELL_REVERSE_LUNGE_TO_HIGH_KNEE_AND_PRESS = 24
    DUMBBELL_SIDE_LUNGE = 25
    ELEVATED_FRONT_FOOT_BARBELL_SPLIT_SQUAT = 26
    FRONT_FOOT_ELEVATED_DUMBBELL_SPLIT_SQUAT = 27
    GUNSLINGER_LUNGE = 28
    LAWNMOWER_LUNGE = 29
    LOW_LUNGE_WITH_ISOMETRIC_ADDUCTION = 30
    LOW_SIDE_TO_SIDE_LUNGE = 31
    LUNGE = 32
    WEIGHTED_LUNGE = 33
    LUNGE_WITH_ARM_REACH = 34
    LUNGE_WITH_DIAGONAL_REACH = 35
    LUNGE_WITH_SIDE_BEND = 36
    OFFSET_DUMBBELL_LUNGE = 37
    OFFSET_DUMBBELL_REVERSE_LUNGE = 38
    OVERHEAD_BULGARIAN_SPLIT_SQUAT = 39
    OVERHEAD_DUMBBELL_REVERSE_LUNGE = 40
    OVERHEAD_DUMBBELL_SPLIT_SQUAT = 41
    OVERHEAD_LUNGE_WITH_ROTATION = 42
    REVERSE_BARBELL_BOX_LUNGE = 43
    REVERSE_BOX_LUNGE = 44
    REVERSE_DUMBBELL_BOX_LUNGE = 45
    REVERSE_DUMBBELL_CROSSOVER_LUNGE = 46
    REVERSE_DUMBBELL_DIAGONAL_LUNGE = 47
    REVERSE_LUNGE_WITH_REACH_BACK = 48
    WEIGHTED_REVERSE_LUNGE_WITH_REACH_BACK = 49
    REVERSE_LUNGE_WITH_TWIST_AND_OVERHEAD_REACH = 50
    WEIGHTED_REVERSE_LUNGE_WITH_TWIST_AND_OVERHEAD_REACH = 51
    REVERSE_SLIDING_BOX_LUNGE = 52
    WEIGHTED_REVERSE_SLIDING_BOX_LUNGE = 53
    REVERSE_SLIDING_LUNGE = 54
    WEIGHTED_REVERSE_SLIDING_LUNGE = 55
    RUNNERS_LUNGE_TO_BALANCE = 56
    WEIGHTED_RUNNERS_LUNGE_TO_BALANCE = 57
    SHIFTING_SIDE_LUNGE = 58
    SIDE_AND_CROSSOVER_LUNGE = 59
    WEIGHTED_SIDE_AND_CROSSOVER_LUNGE = 60
    SIDE_LUNGE = 61
    WEIGHTED_SIDE_LUNGE = 62
    SIDE_LUNGE_AND_PRESS = 63
    SIDE_LUNGE_JUMP_OFF = 64
    SIDE_LUNGE_SWEEP = 65
    WEIGHTED_SIDE_LUNGE_SWEEP = 66
    SIDE_LUNGE_TO_CROSSOVER_TAP = 67
    WEIGHTED_SIDE_LUNGE_TO_CROSSOVER_TAP = 68
    SIDE_TO_SIDE_LUNGE_CHOPS = 69
    WEIGHTED_SIDE_TO_SIDE_LUNGE_CHOPS = 70
    SIFF_JUMP_LUNGE = 71
    WEIGHTED_SIFF_JUMP_LUNGE = 72
    SINGLE_ARM_REVERSE_LUNGE_AND_PRESS = 73
    SLIDING_LATERAL_LUNGE = 74
    WEIGHTED_SLIDING_LATERAL_LUNGE = 75
    WALKING_BARBELL_LUNGE = 76
    WALKING_DUMBBELL_LUNGE = 77
    WALKING_LUNGE = 78
    WEIGHTED_WALKING_LUNGE = 79
    WIDE_GRIP_OVERHEAD_BARBELL_SPLIT_SQUAT = 80


class OlympicLiftExerciseName(Enum):
    BARBELL_HANG_POWER_CLEAN = 0
    BARBELL_HANG_SQUAT_CLEAN = 1
    BARBELL_POWER_CLEAN = 2
    BARBELL_POWER_SNATCH = 3
    BARBELL_SQUAT_CLEAN = 4
    CLEAN_AND_JERK = 5
    BARBELL_HANG_POWER_SNATCH = 6
    BARBELL_HANG_PULL = 7
    BARBELL_HIGH_PULL = 8
    BARBELL_SNATCH = 9
    BARBELL_SPLIT_JERK = 10
    CLEAN = 11
    DUMBBELL_CLEAN = 12
    DUMBBELL_HANG_PULL = 13
    ONE_HAND_DUMBBELL_SPLIT_SNATCH = 14
    PUSH_JERK = 15
    SINGLE_ARM_DUMBBELL_SNATCH = 16
    SINGLE_ARM_HANG_SNATCH = 17
    SINGLE_ARM_KETTLEBELL_SNATCH = 18
    SPLIT_JERK = 19
    SQUAT_CLEAN_AND_JERK = 20


class PlankExerciseName(Enum):
    N45_DEGREE_PLANK = 0
    WEIGHTED_45_DEGREE_PLANK = 1
    N90_DEGREE_STATIC_HOLD = 2
    WEIGHTED_90_DEGREE_STATIC_HOLD = 3
    BEAR_CRAWL = 4
    WEIGHTED_BEAR_CRAWL = 5
    CROSS_BODY_MOUNTAIN_CLIMBER = 6
    WEIGHTED_CROSS_BODY_MOUNTAIN_CLIMBER = 7
    ELBOW_PLANK_PIKE_JACKS = 8
    WEIGHTED_ELBOW_PLANK_PIKE_JACKS = 9
    ELEVATED_FEET_PLANK = 10
    WEIGHTED_ELEVATED_FEET_PLANK = 11
    ELEVATOR_ABS = 12
    WEIGHTED_ELEVATOR_ABS = 13
    EXTENDED_PLANK = 14
    WEIGHTED_EXTENDED_PLANK = 15
    FULL_PLANK_PASSE_TWIST = 16
    WEIGHTED_FULL_PLANK_PASSE_TWIST = 17
    INCHING_ELBOW_PLANK = 18
    WEIGHTED_INCHING_ELBOW_PLANK = 19
    INCHWORM_TO_SIDE_PLANK = 20
    WEIGHTED_INCHWORM_TO_SIDE_PLANK = 21
    KNEELING_PLANK = 22
    WEIGHTED_KNEELING_PLANK = 23
    KNEELING_SIDE_PLANK_WITH_LEG_LIFT = 24
    WEIGHTED_KNEELING_SIDE_PLANK_WITH_LEG_LIFT = 25
    LATERAL_ROLL = 26
    WEIGHTED_LATERAL_ROLL = 27
    LYING_REVERSE_PLANK = 28
    WEIGHTED_LYING_REVERSE_PLANK = 29
    MEDICINE_BALL_MOUNTAIN_CLIMBER = 30
    WEIGHTED_MEDICINE_BALL_MOUNTAIN_CLIMBER = 31
    MODIFIED_MOUNTAIN_CLIMBER_AND_EXTENSION = 32
    WEIGHTED_MODIFIED_MOUNTAIN_CLIMBER_AND_EXTENSION = 33
    MOUNTAIN_CLIMBER = 34
    WEIGHTED_MOUNTAIN_CLIMBER = 35
    MOUNTAIN_CLIMBER_ON_SLIDING_DISCS = 36
    WEIGHTED_MOUNTAIN_CLIMBER_ON_SLIDING_DISCS = 37
    MOUNTAIN_CLIMBER_WITH_FEET_ON_BOSU_BALL = 38
    WEIGHTED_MOUNTAIN_CLIMBER_WITH_FEET_ON_BOSU_BALL = 39
    MOUNTAIN_CLIMBER_WITH_HANDS_ON_BENCH = 40
    MOUNTAIN_CLIMBER_WITH_HANDS_ON_SWISS_BALL = 41
    WEIGHTED_MOUNTAIN_CLIMBER_WITH_HANDS_ON_SWISS_BALL = 42
    PLANK = 43
    PLANK_JACKS_WITH_FEET_ON_SLIDING_DISCS = 44
    WEIGHTED_PLANK_JACKS_WITH_FEET_ON_SLIDING_DISCS = 45
    PLANK_KNEE_TWIST = 46
    WEIGHTED_PLANK_KNEE_TWIST = 47
    PLANK_PIKE_JUMPS = 48
    WEIGHTED_PLANK_PIKE_JUMPS = 49
    PLANK_PIKES = 50
    WEIGHTED_PLANK_PIKES = 51
    PLANK_TO_STAND_UP = 52
    WEIGHTED_PLANK_TO_STAND_UP = 53
    PLANK_WITH_ARM_RAISE = 54
    WEIGHTED_PLANK_WITH_ARM_RAISE = 55
    PLANK_WITH_KNEE_TO_ELBOW = 56
    WEIGHTED_PLANK_WITH_KNEE_TO_ELBOW = 57
    PLANK_WITH_OBLIQUE_CRUNCH = 58
    WEIGHTED_PLANK_WITH_OBLIQUE_CRUNCH = 59
    PLYOMETRIC_SIDE_PLANK = 60
    WEIGHTED_PLYOMETRIC_SIDE_PLANK = 61
    ROLLING_SIDE_PLANK = 62
    WEIGHTED_ROLLING_SIDE_PLANK = 63
    SIDE_KICK_PLANK = 64
    WEIGHTED_SIDE_KICK_PLANK = 65
    SIDE_PLANK = 66
    WEIGHTED_SIDE_PLANK = 67
    SIDE_PLANK_AND_ROW = 68
    WEIGHTED_SIDE_PLANK_AND_ROW = 69
    SIDE_PLANK_LIFT = 70
    WEIGHTED_SIDE_PLANK_LIFT = 71
    SIDE_PLANK_WITH_ELBOW_ON_BOSU_BALL = 72
    WEIGHTED_SIDE_PLANK_WITH_ELBOW_ON_BOSU_BALL = 73
    SIDE_PLANK_WITH_FEET_ON_BENCH = 74
    WEIGHTED_SIDE_PLANK_WITH_FEET_ON_BENCH = 75
    SIDE_PLANK_WITH_KNEE_CIRCLE = 76
    WEIGHTED_SIDE_PLANK_WITH_KNEE_CIRCLE = 77
    SIDE_PLANK_WITH_KNEE_TUCK = 78
    WEIGHTED_SIDE_PLANK_WITH_KNEE_TUCK = 79
    SIDE_PLANK_WITH_LEG_LIFT = 80
    WEIGHTED_SIDE_PLANK_WITH_LEG_LIFT = 81
    SIDE_PLANK_WITH_REACH_UNDER = 82
    WEIGHTED_SIDE_PLANK_WITH_REACH_UNDER = 83
    SINGLE_LEG_ELEVATED_FEET_PLANK = 84
    WEIGHTED_SINGLE_LEG_ELEVATED_FEET_PLANK = 85
    SINGLE_LEG_FLEX_AND_EXTEND = 86
    WEIGHTED_SINGLE_LEG_FLEX_AND_EXTEND = 87
    SINGLE_LEG_SIDE_PLANK = 88
    WEIGHTED_SINGLE_LEG_SIDE_PLANK = 89
    SPIDERMAN_PLANK = 90
    WEIGHTED_SPIDERMAN_PLANK = 91
    STRAIGHT_ARM_PLANK = 92
    WEIGHTED_STRAIGHT_ARM_PLANK = 93
    STRAIGHT_ARM_PLANK_WITH_SHOULDER_TOUCH = 94
    WEIGHTED_STRAIGHT_ARM_PLANK_WITH_SHOULDER_TOUCH = 95
    SWISS_BALL_PLANK = 96
    WEIGHTED_SWISS_BALL_PLANK = 97
    SWISS_BALL_PLANK_LEG_LIFT = 98
    WEIGHTED_SWISS_BALL_PLANK_LEG_LIFT = 99
    SWISS_BALL_PLANK_LEG_LIFT_AND_HOLD = 100
    SWISS_BALL_PLANK_WITH_FEET_ON_BENCH = 101
    WEIGHTED_SWISS_BALL_PLANK_WITH_FEET_ON_BENCH = 102
    SWISS_BALL_PRONE_JACKKNIFE = 103
    WEIGHTED_SWISS_BALL_PRONE_JACKKNIFE = 104
    SWISS_BALL_SIDE_PLANK = 105
    WEIGHTED_SWISS_BALL_SIDE_PLANK = 106
    THREE_WAY_PLANK = 107
    WEIGHTED_THREE_WAY_PLANK = 108
    TOWEL_PLANK_AND_KNEE_IN = 109
    WEIGHTED_TOWEL_PLANK_AND_KNEE_IN = 110
    T_STABILIZATION = 111
    WEIGHTED_T_STABILIZATION = 112
    TURKISH_GET_UP_TO_SIDE_PLANK = 113
    WEIGHTED_TURKISH_GET_UP_TO_SIDE_PLANK = 114
    TWO_POINT_PLANK = 115
    WEIGHTED_TWO_POINT_PLANK = 116
    WEIGHTED_PLANK = 117
    WIDE_STANCE_PLANK_WITH_DIAGONAL_ARM_LIFT = 118
    WEIGHTED_WIDE_STANCE_PLANK_WITH_DIAGONAL_ARM_LIFT = 119
    WIDE_STANCE_PLANK_WITH_DIAGONAL_LEG_LIFT = 120
    WEIGHTED_WIDE_STANCE_PLANK_WITH_DIAGONAL_LEG_LIFT = 121
    WIDE_STANCE_PLANK_WITH_LEG_LIFT = 122
    WEIGHTED_WIDE_STANCE_PLANK_WITH_LEG_LIFT = 123
    WIDE_STANCE_PLANK_WITH_OPPOSITE_ARM_AND_LEG_LIFT = 124
    WEIGHTED_MOUNTAIN_CLIMBER_WITH_HANDS_ON_BENCH = 125
    WEIGHTED_SWISS_BALL_PLANK_LEG_LIFT_AND_HOLD = 126
    WEIGHTED_WIDE_STANCE_PLANK_WITH_OPPOSITE_ARM_AND_LEG_LIFT = 127
    PLANK_WITH_FEET_ON_SWISS_BALL = 128
    SIDE_PLANK_TO_PLANK_WITH_REACH_UNDER = 129
    BRIDGE_WITH_GLUTE_LOWER_LIFT = 130
    BRIDGE_ONE_LEG_BRIDGE = 131
    PLANK_WITH_ARM_VARIATIONS = 132
    PLANK_WITH_LEG_LIFT = 133
    REVERSE_PLANK_WITH_LEG_PULL = 134


class PlyoExerciseName(Enum):
    ALTERNATING_JUMP_LUNGE = 0
    WEIGHTED_ALTERNATING_JUMP_LUNGE = 1
    BARBELL_JUMP_SQUAT = 2
    BODY_WEIGHT_JUMP_SQUAT = 3
    WEIGHTED_JUMP_SQUAT = 4
    CROSS_KNEE_STRIKE = 5
    WEIGHTED_CROSS_KNEE_STRIKE = 6
    DEPTH_JUMP = 7
    WEIGHTED_DEPTH_JUMP = 8
    DUMBBELL_JUMP_SQUAT = 9
    DUMBBELL_SPLIT_JUMP = 10
    FRONT_KNEE_STRIKE = 11
    WEIGHTED_FRONT_KNEE_STRIKE = 12
    HIGH_BOX_JUMP = 13
    WEIGHTED_HIGH_BOX_JUMP = 14
    ISOMETRIC_EXPLOSIVE_BODY_WEIGHT_JUMP_SQUAT = 15
    WEIGHTED_ISOMETRIC_EXPLOSIVE_JUMP_SQUAT = 16
    LATERAL_LEAP_AND_HOP = 17
    WEIGHTED_LATERAL_LEAP_AND_HOP = 18
    LATERAL_PLYO_SQUATS = 19
    WEIGHTED_LATERAL_PLYO_SQUATS = 20
    LATERAL_SLIDE = 21
    WEIGHTED_LATERAL_SLIDE = 22
    MEDICINE_BALL_OVERHEAD_THROWS = 23
    MEDICINE_BALL_SIDE_THROW = 24
    MEDICINE_BALL_SLAM = 25
    SIDE_TO_SIDE_MEDICINE_BALL_THROWS = 26
    SIDE_TO_SIDE_SHUFFLE_JUMP = 27
    WEIGHTED_SIDE_TO_SIDE_SHUFFLE_JUMP = 28
    SQUAT_JUMP_ONTO_BOX = 29
    WEIGHTED_SQUAT_JUMP_ONTO_BOX = 30
    SQUAT_JUMPS_IN_AND_OUT = 31
    WEIGHTED_SQUAT_JUMPS_IN_AND_OUT = 32


class PullUpExerciseName(Enum):
    BANDED_PULL_UPS = 0
    N30_DEGREE_LAT_PULLDOWN = 1
    BAND_ASSISTED_CHIN_UP = 2
    CLOSE_GRIP_CHIN_UP = 3
    WEIGHTED_CLOSE_GRIP_CHIN_UP = 4
    CLOSE_GRIP_LAT_PULLDOWN = 5
    CROSSOVER_CHIN_UP = 6
    WEIGHTED_CROSSOVER_CHIN_UP = 7
    EZ_BAR_PULLOVER = 8
    HANGING_HURDLE = 9
    WEIGHTED_HANGING_HURDLE = 10
    KNEELING_LAT_PULLDOWN = 11
    KNEELING_UNDERHAND_GRIP_LAT_PULLDOWN = 12
    LAT_PULLDOWN = 13
    MIXED_GRIP_CHIN_UP = 14
    WEIGHTED_MIXED_GRIP_CHIN_UP = 15
    MIXED_GRIP_PULL_UP = 16
    WEIGHTED_MIXED_GRIP_PULL_UP = 17
    REVERSE_GRIP_PULLDOWN = 18
    STANDING_CABLE_PULLOVER = 19
    STRAIGHT_ARM_PULLDOWN = 20
    SWISS_BALL_EZ_BAR_PULLOVER = 21
    TOWEL_PULL_UP = 22
    WEIGHTED_TOWEL_PULL_UP = 23
    WEIGHTED_PULL_UP = 24
    WIDE_GRIP_LAT_PULLDOWN = 25
    WIDE_GRIP_PULL_UP = 26
    WEIGHTED_WIDE_GRIP_PULL_UP = 27
    BURPEE_PULL_UP = 28
    WEIGHTED_BURPEE_PULL_UP = 29
    JUMPING_PULL_UPS = 30
    WEIGHTED_JUMPING_PULL_UPS = 31
    KIPPING_PULL_UP = 32
    WEIGHTED_KIPPING_PULL_UP = 33
    L_PULL_UP = 34
    WEIGHTED_L_PULL_UP = 35
    SUSPENDED_CHIN_UP = 36
    WEIGHTED_SUSPENDED_CHIN_UP = 37
    PULL_UP = 38


class PushUpExerciseName(Enum):
    CHEST_PRESS_WITH_BAND = 0
    ALTERNATING_STAGGERED_PUSH_UP = 1
    WEIGHTED_ALTERNATING_STAGGERED_PUSH_UP = 2
    ALTERNATING_HANDS_MEDICINE_BALL_PUSH_UP = 3
    WEIGHTED_ALTERNATING_HANDS_MEDICINE_BALL_PUSH_UP = 4
    BOSU_BALL_PUSH_UP = 5
    WEIGHTED_BOSU_BALL_PUSH_UP = 6
    CLAPPING_PUSH_UP = 7
    WEIGHTED_CLAPPING_PUSH_UP = 8
    CLOSE_GRIP_MEDICINE_BALL_PUSH_UP = 9
    WEIGHTED_CLOSE_GRIP_MEDICINE_BALL_PUSH_UP = 10
    CLOSE_HANDS_PUSH_UP = 11
    WEIGHTED_CLOSE_HANDS_PUSH_UP = 12
    DECLINE_PUSH_UP = 13
    WEIGHTED_DECLINE_PUSH_UP = 14
    DIAMOND_PUSH_UP = 15
    WEIGHTED_DIAMOND_PUSH_UP = 16
    EXPLOSIVE_CROSSOVER_PUSH_UP = 17
    WEIGHTED_EXPLOSIVE_CROSSOVER_PUSH_UP = 18
    EXPLOSIVE_PUSH_UP = 19
    WEIGHTED_EXPLOSIVE_PUSH_UP = 20
    FEET_ELEVATED_SIDE_TO_SIDE_PUSH_UP = 21
    WEIGHTED_FEET_ELEVATED_SIDE_TO_SIDE_PUSH_UP = 22
    HAND_RELEASE_PUSH_UP = 23
    WEIGHTED_HAND_RELEASE_PUSH_UP = 24
    HANDSTAND_PUSH_UP = 25
    WEIGHTED_HANDSTAND_PUSH_UP = 26
    INCLINE_PUSH_UP = 27
    WEIGHTED_INCLINE_PUSH_UP = 28
    ISOMETRIC_EXPLOSIVE_PUSH_UP = 29
    WEIGHTED_ISOMETRIC_EXPLOSIVE_PUSH_UP = 30
    JUDO_PUSH_UP = 31
    WEIGHTED_JUDO_PUSH_UP = 32
    KNEELING_PUSH_UP = 33
    WEIGHTED_KNEELING_PUSH_UP = 34
    MEDICINE_BALL_CHEST_PASS = 35
    MEDICINE_BALL_PUSH_UP = 36
    WEIGHTED_MEDICINE_BALL_PUSH_UP = 37
    ONE_ARM_PUSH_UP = 38
    WEIGHTED_ONE_ARM_PUSH_UP = 39
    WEIGHTED_PUSH_UP = 40
    PUSH_UP_AND_ROW = 41
    WEIGHTED_PUSH_UP_AND_ROW = 42
    PUSH_UP_PLUS = 43
    WEIGHTED_PUSH_UP_PLUS = 44
    PUSH_UP_WITH_FEET_ON_SWISS_BALL = 45
    WEIGHTED_PUSH_UP_WITH_FEET_ON_SWISS_BALL = 46
    PUSH_UP_WITH_ONE_HAND_ON_MEDICINE_BALL = 47
    WEIGHTED_PUSH_UP_WITH_ONE_HAND_ON_MEDICINE_BALL = 48
    SHOULDER_PUSH_UP = 49
    WEIGHTED_SHOULDER_PUSH_UP = 50
    SINGLE_ARM_MEDICINE_BALL_PUSH_UP = 51
    WEIGHTED_SINGLE_ARM_MEDICINE_BALL_PUSH_UP = 52
    SPIDERMAN_PUSH_UP = 53
    WEIGHTED_SPIDERMAN_PUSH_UP = 54
    STACKED_FEET_PUSH_UP = 55
    WEIGHTED_STACKED_FEET_PUSH_UP = 56
    STAGGERED_HANDS_PUSH_UP = 57
    WEIGHTED_STAGGERED_HANDS_PUSH_UP = 58
    SUSPENDED_PUSH_UP = 59
    WEIGHTED_SUSPENDED_PUSH_UP = 60
    SWISS_BALL_PUSH_UP = 61
    WEIGHTED_SWISS_BALL_PUSH_UP = 62
    SWISS_BALL_PUSH_UP_PLUS = 63
    WEIGHTED_SWISS_BALL_PUSH_UP_PLUS = 64
    T_PUSH_UP = 65
    WEIGHTED_T_PUSH_UP = 66
    TRIPLE_STOP_PUSH_UP = 67
    WEIGHTED_TRIPLE_STOP_PUSH_UP = 68
    WIDE_HANDS_PUSH_UP = 69
    WEIGHTED_WIDE_HANDS_PUSH_UP = 70
    PARALLETTE_HANDSTAND_PUSH_UP = 71
    WEIGHTED_PARALLETTE_HANDSTAND_PUSH_UP = 72
    RING_HANDSTAND_PUSH_UP = 73
    WEIGHTED_RING_HANDSTAND_PUSH_UP = 74
    RING_PUSH_UP = 75
    WEIGHTED_RING_PUSH_UP = 76
    PUSH_UP = 77
    PILATES_PUSHUP = 78


class RowExerciseName(Enum):
    BARBELL_STRAIGHT_LEG_DEADLIFT_TO_ROW = 0
    CABLE_ROW_STANDING = 1
    DUMBBELL_ROW = 2
    ELEVATED_FEET_INVERTED_ROW = 3
    WEIGHTED_ELEVATED_FEET_INVERTED_ROW = 4
    FACE_PULL = 5
    FACE_PULL_WITH_EXTERNAL_ROTATION = 6
    INVERTED_ROW_WITH_FEET_ON_SWISS_BALL = 7
    WEIGHTED_INVERTED_ROW_WITH_FEET_ON_SWISS_BALL = 8
    KETTLEBELL_ROW = 9
    MODIFIED_INVERTED_ROW = 10
    WEIGHTED_MODIFIED_INVERTED_ROW = 11
    NEUTRAL_GRIP_ALTERNATING_DUMBBELL_ROW = 12
    ONE_ARM_BENT_OVER_ROW = 13
    ONE_LEGGED_DUMBBELL_ROW = 14
    RENEGADE_ROW = 15
    REVERSE_GRIP_BARBELL_ROW = 16
    ROPE_HANDLE_CABLE_ROW = 17
    SEATED_CABLE_ROW = 18
    SEATED_DUMBBELL_ROW = 19
    SINGLE_ARM_CABLE_ROW = 20
    SINGLE_ARM_CABLE_ROW_AND_ROTATION = 21
    SINGLE_ARM_INVERTED_ROW = 22
    WEIGHTED_SINGLE_ARM_INVERTED_ROW = 23
    SINGLE_ARM_NEUTRAL_GRIP_DUMBBELL_ROW = 24
    SINGLE_ARM_NEUTRAL_GRIP_DUMBBELL_ROW_AND_ROTATION = 25
    SUSPENDED_INVERTED_ROW = 26
    WEIGHTED_SUSPENDED_INVERTED_ROW = 27
    T_BAR_ROW = 28
    TOWEL_GRIP_INVERTED_ROW = 29
    WEIGHTED_TOWEL_GRIP_INVERTED_ROW = 30
    UNDERHAND_GRIP_CABLE_ROW = 31
    V_GRIP_CABLE_ROW = 32
    WIDE_GRIP_SEATED_CABLE_ROW = 33


class ShoulderPressExerciseName(Enum):
    ALTERNATING_DUMBBELL_SHOULDER_PRESS = 0
    ARNOLD_PRESS = 1
    BARBELL_FRONT_SQUAT_TO_PUSH_PRESS = 2
    BARBELL_PUSH_PRESS = 3
    BARBELL_SHOULDER_PRESS = 4
    DEAD_CURL_PRESS = 5
    DUMBBELL_ALTERNATING_SHOULDER_PRESS_AND_TWIST = 6
    DUMBBELL_HAMMER_CURL_TO_LUNGE_TO_PRESS = 7
    DUMBBELL_PUSH_PRESS = 8
    FLOOR_INVERTED_SHOULDER_PRESS = 9
    WEIGHTED_FLOOR_INVERTED_SHOULDER_PRESS = 10
    INVERTED_SHOULDER_PRESS = 11
    WEIGHTED_INVERTED_SHOULDER_PRESS = 12
    ONE_ARM_PUSH_PRESS = 13
    OVERHEAD_BARBELL_PRESS = 14
    OVERHEAD_DUMBBELL_PRESS = 15
    SEATED_BARBELL_SHOULDER_PRESS = 16
    SEATED_DUMBBELL_SHOULDER_PRESS = 17
    SINGLE_ARM_DUMBBELL_SHOULDER_PRESS = 18
    SINGLE_ARM_STEP_UP_AND_PRESS = 19
    SMITH_MACHINE_OVERHEAD_PRESS = 20
    SPLIT_STANCE_HAMMER_CURL_TO_PRESS = 21
    SWISS_BALL_DUMBBELL_SHOULDER_PRESS = 22
    WEIGHT_PLATE_FRONT_RAISE = 23


class ShoulderStabilityExerciseName(Enum):
    N90_DEGREE_CABLE_EXTERNAL_ROTATION = 0
    BAND_EXTERNAL_ROTATION = 1
    BAND_INTERNAL_ROTATION = 2
    BENT_ARM_LATERAL_RAISE_AND_EXTERNAL_ROTATION = 3
    CABLE_EXTERNAL_ROTATION = 4
    DUMBBELL_FACE_PULL_WITH_EXTERNAL_ROTATION = 5
    FLOOR_I_RAISE = 6
    WEIGHTED_FLOOR_I_RAISE = 7
    FLOOR_T_RAISE = 8
    WEIGHTED_FLOOR_T_RAISE = 9
    FLOOR_Y_RAISE = 10
    WEIGHTED_FLOOR_Y_RAISE = 11
    INCLINE_I_RAISE = 12
    WEIGHTED_INCLINE_I_RAISE = 13
    INCLINE_L_RAISE = 14
    WEIGHTED_INCLINE_L_RAISE = 15
    INCLINE_T_RAISE = 16
    WEIGHTED_INCLINE_T_RAISE = 17
    INCLINE_W_RAISE = 18
    WEIGHTED_INCLINE_W_RAISE = 19
    INCLINE_Y_RAISE = 20
    WEIGHTED_INCLINE_Y_RAISE = 21
    LYING_EXTERNAL_ROTATION = 22
    SEATED_DUMBBELL_EXTERNAL_ROTATION = 23
    STANDING_L_RAISE = 24
    SWISS_BALL_I_RAISE = 25
    WEIGHTED_SWISS_BALL_I_RAISE = 26
    SWISS_BALL_T_RAISE = 27
    WEIGHTED_SWISS_BALL_T_RAISE = 28
    SWISS_BALL_W_RAISE = 29
    WEIGHTED_SWISS_BALL_W_RAISE = 30
    SWISS_BALL_Y_RAISE = 31
    WEIGHTED_SWISS_BALL_Y_RAISE = 32


class ShrugExerciseName(Enum):
    BARBELL_JUMP_SHRUG = 0
    BARBELL_SHRUG = 1
    BARBELL_UPRIGHT_ROW = 2
    BEHIND_THE_BACK_SMITH_MACHINE_SHRUG = 3
    DUMBBELL_JUMP_SHRUG = 4
    DUMBBELL_SHRUG = 5
    DUMBBELL_UPRIGHT_ROW = 6
    INCLINE_DUMBBELL_SHRUG = 7
    OVERHEAD_BARBELL_SHRUG = 8
    OVERHEAD_DUMBBELL_SHRUG = 9
    SCAPTION_AND_SHRUG = 10
    SCAPULAR_RETRACTION = 11
    SERRATUS_CHAIR_SHRUG = 12
    WEIGHTED_SERRATUS_CHAIR_SHRUG = 13
    SERRATUS_SHRUG = 14
    WEIGHTED_SERRATUS_SHRUG = 15
    WIDE_GRIP_JUMP_SHRUG = 16


class SitUpExerciseName(Enum):
    ALTERNATING_SIT_UP = 0
    WEIGHTED_ALTERNATING_SIT_UP = 1
    BENT_KNEE_V_UP = 2
    WEIGHTED_BENT_KNEE_V_UP = 3
    BUTTERFLY_SIT_UP = 4
    WEIGHTED_BUTTERFLY_SITUP = 5
    CROSS_PUNCH_ROLL_UP = 6
    WEIGHTED_CROSS_PUNCH_ROLL_UP = 7
    CROSSED_ARMS_SIT_UP = 8
    WEIGHTED_CROSSED_ARMS_SIT_UP = 9
    GET_UP_SIT_UP = 10
    WEIGHTED_GET_UP_SIT_UP = 11
    HOVERING_SIT_UP = 12
    WEIGHTED_HOVERING_SIT_UP = 13
    KETTLEBELL_SIT_UP = 14
    MEDICINE_BALL_ALTERNATING_V_UP = 15
    MEDICINE_BALL_SIT_UP = 16
    MEDICINE_BALL_V_UP = 17
    MODIFIED_SIT_UP = 18
    NEGATIVE_SIT_UP = 19
    ONE_ARM_FULL_SIT_UP = 20
    RECLINING_CIRCLE = 21
    WEIGHTED_RECLINING_CIRCLE = 22
    REVERSE_CURL_UP = 23
    WEIGHTED_REVERSE_CURL_UP = 24
    SINGLE_LEG_SWISS_BALL_JACKKNIFE = 25
    WEIGHTED_SINGLE_LEG_SWISS_BALL_JACKKNIFE = 26
    THE_TEASER = 27
    THE_TEASER_WEIGHTED = 28
    THREE_PART_ROLL_DOWN = 29
    WEIGHTED_THREE_PART_ROLL_DOWN = 30
    V_UP = 31
    WEIGHTED_V_UP = 32
    WEIGHTED_RUSSIAN_TWIST_ON_SWISS_BALL = 33
    WEIGHTED_SIT_UP = 34
    X_ABS = 35
    WEIGHTED_X_ABS = 36
    SIT_UP = 37


class SquatExerciseName(Enum):
    LEG_PRESS = 0
    BACK_SQUAT_WITH_BODY_BAR = 1
    BACK_SQUATS = 2
    WEIGHTED_BACK_SQUATS = 3
    BALANCING_SQUAT = 4
    WEIGHTED_BALANCING_SQUAT = 5
    BARBELL_BACK_SQUAT = 6
    BARBELL_BOX_SQUAT = 7
    BARBELL_FRONT_SQUAT = 8
    BARBELL_HACK_SQUAT = 9
    BARBELL_HANG_SQUAT_SNATCH = 10
    BARBELL_LATERAL_STEP_UP = 11
    BARBELL_QUARTER_SQUAT = 12
    BARBELL_SIFF_SQUAT = 13
    BARBELL_SQUAT_SNATCH = 14
    BARBELL_SQUAT_WITH_HEELS_RAISED = 15
    BARBELL_STEPOVER = 16
    BARBELL_STEP_UP = 17
    BENCH_SQUAT_WITH_ROTATIONAL_CHOP = 18
    WEIGHTED_BENCH_SQUAT_WITH_ROTATIONAL_CHOP = 19
    BODY_WEIGHT_WALL_SQUAT = 20
    WEIGHTED_WALL_SQUAT = 21
    BOX_STEP_SQUAT = 22
    WEIGHTED_BOX_STEP_SQUAT = 23
    BRACED_SQUAT = 24
    CROSSED_ARM_BARBELL_FRONT_SQUAT = 25
    CROSSOVER_DUMBBELL_STEP_UP = 26
    DUMBBELL_FRONT_SQUAT = 27
    DUMBBELL_SPLIT_SQUAT = 28
    DUMBBELL_SQUAT = 29
    DUMBBELL_SQUAT_CLEAN = 30
    DUMBBELL_STEPOVER = 31
    DUMBBELL_STEP_UP = 32
    ELEVATED_SINGLE_LEG_SQUAT = 33
    WEIGHTED_ELEVATED_SINGLE_LEG_SQUAT = 34
    FIGURE_FOUR_SQUATS = 35
    WEIGHTED_FIGURE_FOUR_SQUATS = 36
    GOBLET_SQUAT = 37
    KETTLEBELL_SQUAT = 38
    KETTLEBELL_SWING_OVERHEAD = 39
    KETTLEBELL_SWING_WITH_FLIP_TO_SQUAT = 40
    LATERAL_DUMBBELL_STEP_UP = 41
    ONE_LEGGED_SQUAT = 42
    OVERHEAD_DUMBBELL_SQUAT = 43
    OVERHEAD_SQUAT = 44
    PARTIAL_SINGLE_LEG_SQUAT = 45
    WEIGHTED_PARTIAL_SINGLE_LEG_SQUAT = 46
    PISTOL_SQUAT = 47
    WEIGHTED_PISTOL_SQUAT = 48
    PLIE_SLIDES = 49
    WEIGHTED_PLIE_SLIDES = 50
    PLIE_SQUAT = 51
    WEIGHTED_PLIE_SQUAT = 52
    PRISONER_SQUAT = 53
    WEIGHTED_PRISONER_SQUAT = 54
    SINGLE_LEG_BENCH_GET_UP = 55
    WEIGHTED_SINGLE_LEG_BENCH_GET_UP = 56
    SINGLE_LEG_BENCH_SQUAT = 57
    WEIGHTED_SINGLE_LEG_BENCH_SQUAT = 58
    SINGLE_LEG_SQUAT_ON_SWISS_BALL = 59
    WEIGHTED_SINGLE_LEG_SQUAT_ON_SWISS_BALL = 60
    SQUAT = 61
    WEIGHTED_SQUAT = 62
    SQUATS_WITH_BAND = 63
    STAGGERED_SQUAT = 64
    WEIGHTED_STAGGERED_SQUAT = 65
    STEP_UP = 66
    WEIGHTED_STEP_UP = 67
    SUITCASE_SQUATS = 68
    SUMO_SQUAT = 69
    SUMO_SQUAT_SLIDE_IN = 70
    WEIGHTED_SUMO_SQUAT_SLIDE_IN = 71
    SUMO_SQUAT_TO_HIGH_PULL = 72
    SUMO_SQUAT_TO_STAND = 73
    WEIGHTED_SUMO_SQUAT_TO_STAND = 74
    SUMO_SQUAT_WITH_ROTATION = 75
    WEIGHTED_SUMO_SQUAT_WITH_ROTATION = 76
    SWISS_BALL_BODY_WEIGHT_WALL_SQUAT = 77
    WEIGHTED_SWISS_BALL_WALL_SQUAT = 78
    THRUSTERS = 79
    UNEVEN_SQUAT = 80
    WEIGHTED_UNEVEN_SQUAT = 81
    WAIST_SLIMMING_SQUAT = 82
    WALL_BALL = 83
    WIDE_STANCE_BARBELL_SQUAT = 84
    WIDE_STANCE_GOBLET_SQUAT = 85
    ZERCHER_SQUAT = 86
    KBS_OVERHEAD = 87
    SQUAT_AND_SIDE_KICK = 88
    SQUAT_JUMPS_IN_N_OUT = 89
    PILATES_PLIE_SQUATS_PARALLEL_TURNED_OUT_FLAT_AND_HEELS = 90
    RELEVE_STRAIGHT_LEG_AND_KNEE_BENT_WITH_ONE_LEG_VARIATION = 91


class TotalBodyExerciseName(Enum):
    BURPEE = 0
    WEIGHTED_BURPEE = 1
    BURPEE_BOX_JUMP = 2
    WEIGHTED_BURPEE_BOX_JUMP = 3
    HIGH_PULL_BURPEE = 4
    MAN_MAKERS = 5
    ONE_ARM_BURPEE = 6
    SQUAT_THRUSTS = 7
    WEIGHTED_SQUAT_THRUSTS = 8
    SQUAT_PLANK_PUSH_UP = 9
    WEIGHTED_SQUAT_PLANK_PUSH_UP = 10
    STANDING_T_ROTATION_BALANCE = 11
    WEIGHTED_STANDING_T_ROTATION_BALANCE = 12


class TricepsExtensionExerciseName(Enum):
    BENCH_DIP = 0
    WEIGHTED_BENCH_DIP = 1
    BODY_WEIGHT_DIP = 2
    CABLE_KICKBACK = 3
    CABLE_LYING_TRICEPS_EXTENSION = 4
    CABLE_OVERHEAD_TRICEPS_EXTENSION = 5
    DUMBBELL_KICKBACK = 6
    DUMBBELL_LYING_TRICEPS_EXTENSION = 7
    EZ_BAR_OVERHEAD_TRICEPS_EXTENSION = 8
    INCLINE_DIP = 9
    WEIGHTED_INCLINE_DIP = 10
    INCLINE_EZ_BAR_LYING_TRICEPS_EXTENSION = 11
    LYING_DUMBBELL_PULLOVER_TO_EXTENSION = 12
    LYING_EZ_BAR_TRICEPS_EXTENSION = 13
    LYING_TRICEPS_EXTENSION_TO_CLOSE_GRIP_BENCH_PRESS = 14
    OVERHEAD_DUMBBELL_TRICEPS_EXTENSION = 15
    RECLINING_TRICEPS_PRESS = 16
    REVERSE_GRIP_PRESSDOWN = 17
    REVERSE_GRIP_TRICEPS_PRESSDOWN = 18
    ROPE_PRESSDOWN = 19
    SEATED_BARBELL_OVERHEAD_TRICEPS_EXTENSION = 20
    SEATED_DUMBBELL_OVERHEAD_TRICEPS_EXTENSION = 21
    SEATED_EZ_BAR_OVERHEAD_TRICEPS_EXTENSION = 22
    SEATED_SINGLE_ARM_OVERHEAD_DUMBBELL_EXTENSION = 23
    SINGLE_ARM_DUMBBELL_OVERHEAD_TRICEPS_EXTENSION = 24
    SINGLE_DUMBBELL_SEATED_OVERHEAD_TRICEPS_EXTENSION = 25
    SINGLE_LEG_BENCH_DIP_AND_KICK = 26
    WEIGHTED_SINGLE_LEG_BENCH_DIP_AND_KICK = 27
    SINGLE_LEG_DIP = 28
    WEIGHTED_SINGLE_LEG_DIP = 29
    STATIC_LYING_TRICEPS_EXTENSION = 30
    SUSPENDED_DIP = 31
    WEIGHTED_SUSPENDED_DIP = 32
    SWISS_BALL_DUMBBELL_LYING_TRICEPS_EXTENSION = 33
    SWISS_BALL_EZ_BAR_LYING_TRICEPS_EXTENSION = 34
    SWISS_BALL_EZ_BAR_OVERHEAD_TRICEPS_EXTENSION = 35
    TABLETOP_DIP = 36
    WEIGHTED_TABLETOP_DIP = 37
    TRICEPS_EXTENSION_ON_FLOOR = 38
    TRICEPS_PRESSDOWN = 39
    WEIGHTED_DIP = 40


class WarmUpExerciseName(Enum):
    QUADRUPED_ROCKING = 0
    NECK_TILTS = 1
    ANKLE_CIRCLES = 2
    ANKLE_DORSIFLEXION_WITH_BAND = 3
    ANKLE_INTERNAL_ROTATION = 4
    ARM_CIRCLES = 5
    BENT_OVER_REACH_TO_SKY = 6
    CAT_CAMEL = 7
    ELBOW_TO_FOOT_LUNGE = 8
    FORWARD_AND_BACKWARD_LEG_SWINGS = 9
    GROINERS = 10
    INVERTED_HAMSTRING_STRETCH = 11
    LATERAL_DUCK_UNDER = 12
    NECK_ROTATIONS = 13
    OPPOSITE_ARM_AND_LEG_BALANCE = 14
    REACH_ROLL_AND_LIFT = 15
    SCORPION = 16
    SHOULDER_CIRCLES = 17
    SIDE_TO_SIDE_LEG_SWINGS = 18
    SLEEPER_STRETCH = 19
    SLIDE_OUT = 20
    SWISS_BALL_HIP_CROSSOVER = 21
    SWISS_BALL_REACH_ROLL_AND_LIFT = 22
    SWISS_BALL_WINDSHIELD_WIPERS = 23
    THORACIC_ROTATION = 24
    WALKING_HIGH_KICKS = 25
    WALKING_HIGH_KNEES = 26
    WALKING_KNEE_HUGS = 27
    WALKING_LEG_CRADLES = 28
    WALKOUT = 29
    WALKOUT_FROM_PUSH_UP_POSITION = 30


class RunExerciseName(Enum):
    RUN = 0
    WALK = 1
    JOG = 2
    SPRINT = 3


class WaterType(Enum):
    FRESH = 0
    SALT = 1
    EN13319 = 2
    CUSTOM = 3


class TissueModelType(Enum):
    ZHL_16C = 0


class DiveGasStatus(Enum):
    DISABLED = 0
    ENABLED = 1
    BACKUP_ONLY = 2


class DiveAlarmType(Enum):
    DEPTH = 0
    TIME = 1


class DiveBacklightMode(Enum):
    AT_DEPTH = 0
    ALWAYS_ON = 1


class FaveroProduct(Enum):
    ASSIOMA_UNO = 10
    ASSIOMA_DUO = 12


class ClimbProEvent(Enum):
    APPROACH = 0
    START = 1
    COMPLETE = 2


class TapSensitivity(Enum):
    HIGH = 0
    MEDIUM = 1
    LOW = 2


class RadarThreatLevelType(Enum):
    THREAT_UNKNOWN = 0
    THREAT_NONE = 1
    THREAT_APPROACHING = 2
    THREAT_APPROACHING_FAST = 3
